@@ -26,7 +26,6 @@ var NAVTREE =
 [
   [ "StarPU Handbook", "index.html", [
     [ "Introduction", "index.html", [
-      [ "we need to keep 2 blank lines above", "index.html#autotoc_md0", null ],
       [ "Motivation", "index.html#Motivation", null ],
       [ "StarPU in a Nutshell", "index.html#StarPUInANutshell", [
         [ "Codelet and Tasks", "index.html#CodeletAndTasks", null ],
@@ -632,16 +631,16 @@ var NAVTREEINDEX =
 "group__API__Codelet__And__Tasks.html#ga842f80f41741306e78963d5b1cec4b7f",
 "group__API__Data__Interfaces.html#ga3ef8a3c5b91f3d3b048a4e5f51a4c4c0",
 "group__API__Data__Management.html#gaf971c53b3fa3d3746a8ae1f5291c7c4f",
-"group__API__Initialization__and__Termination.html#ga06215a557f489ef2dd936f691e395eb7",
-"group__API__MPI__Support.html#gab1cdef357b93d4f9f332199da819b792",
-"group__API__OpenMP__Runtime__Support.html#ga2c980c583e9faf124b4446fa90b5ece9",
-"group__API__Perf__Steering.html#gaa3355e070b7f2275deb8616bc3a8bb9b",
-"group__API__SC__Hypervisor.html#gab4e7dd4e4841b9e3db584b903043c3ad",
-"group__API__Task__Lists.html#ga56ae6bd10619777a164ace85197034c4",
+"group__API__Initialization__and__Termination.html#affd5b335a988c417ecb679d5ecf7c489",
+"group__API__MPI__Support.html#gaaf806ce3131edd757470c7401bd41bd7",
+"group__API__OpenMP__Runtime__Support.html#ga1b951f0922d794e6deb2579c81bcf41b",
+"group__API__Perf__Steering.html#ga9715d7c1d761e641fce5c4ec72507d2b",
+"group__API__SC__Hypervisor.html#gaafac498199c6441e2d45c9b4eac8dfe4",
+"group__API__Task__Lists.html#ga37f7421eb2dcf9d808220db8454f0fac",
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block.html",
 "interfacefstarpu__mod_1_1fstarpu__free__noflag.html",
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html",
-"starpu__cusolver_8h.html#a802c617673805d37d62a3213261d121e"
+"starpu__cusolver_8h.html#a78866b909f7e937a43d96beb983c2434"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
