@@ -1,5 +1,7 @@
 var NAVTREEINDEX11 =
 {
+"group__API__Task__Lists.html#ga37f7421eb2dcf9d808220db8454f0fac":[57,8,11],
+"group__API__Task__Lists.html#ga5618612b0ce2f914ab9032474ddf072f":[57,8,1],
 "group__API__Task__Lists.html#ga56ae6bd10619777a164ace85197034c4":[57,8,5],
 "group__API__Task__Lists.html#ga78d4f98e2d6f2f73d453c86ca8ca9e95":[57,8,4],
 "group__API__Task__Lists.html#gabf5bb8daf00f9902ea501009720af19d":[57,8,2],
@@ -230,13 +232,12 @@ var NAVTREEINDEX11 =
 "group__API__Workers.html#structstarpu__worker__collection":[57,14,1],
 "index.html":[0],
 "index.html":[],
-"index.html#ApplicationTaskification":[0,3],
-"index.html#CodeletAndTasks":[0,2,0],
-"index.html#Motivation":[0,1],
-"index.html#ResearchPapers":[0,4],
-"index.html#StarPUDataManagementLibrary":[0,2,1],
-"index.html#StarPUInANutshell":[0,2],
-"index.html#autotoc_md0":[0,0],
+"index.html#ApplicationTaskification":[0,2],
+"index.html#CodeletAndTasks":[0,1,0],
+"index.html#Motivation":[0,0],
+"index.html#ResearchPapers":[0,3],
+"index.html#StarPUDataManagementLibrary":[0,1,1],
+"index.html#StarPUInANutshell":[0,1],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[58,0,0,0],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[59,0,0,0],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[58,0,0,1],
@@ -245,9 +246,8 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[59,0,0,2],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[58,0,0,3],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[59,0,0,3],
-"interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[58,0,0,4],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[59,0,0,4],
+"interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[58,0,0,4],
 "interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[58,0,0,5],
-"interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[59,0,0,5],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[59,0,0,6]
+"interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[59,0,0,5]
 };
