@@ -1,36 +1,37 @@
 var NAVTREEINDEX13 =
 {
 "interfacefstarpu__mod_1_1fstarpu__free__noflag.html":[58,0,0,131],
+"interfacefstarpu__mod_1_1fstarpu__free__noflag.html":[59,0,0,131],
 "interfacefstarpu__mod_1_1fstarpu__free__on__node.html":[59,0,0,132],
 "interfacefstarpu__mod_1_1fstarpu__free__on__node.html":[58,0,0,132],
-"interfacefstarpu__mod_1_1fstarpu__fxt__autostart__profiling.html":[59,0,0,133],
 "interfacefstarpu__mod_1_1fstarpu__fxt__autostart__profiling.html":[58,0,0,133],
+"interfacefstarpu__mod_1_1fstarpu__fxt__autostart__profiling.html":[59,0,0,133],
 "interfacefstarpu__mod_1_1fstarpu__fxt__generate__trace.html":[59,0,0,134],
 "interfacefstarpu__mod_1_1fstarpu__fxt__generate__trace.html":[58,0,0,134],
-"interfacefstarpu__mod_1_1fstarpu__fxt__options__init.html":[59,0,0,135],
 "interfacefstarpu__mod_1_1fstarpu__fxt__options__init.html":[58,0,0,135],
-"interfacefstarpu__mod_1_1fstarpu__fxt__start__profiling.html":[58,0,0,136],
+"interfacefstarpu__mod_1_1fstarpu__fxt__options__init.html":[59,0,0,135],
 "interfacefstarpu__mod_1_1fstarpu__fxt__start__profiling.html":[59,0,0,136],
-"interfacefstarpu__mod_1_1fstarpu__fxt__stop__profiling.html":[58,0,0,137],
+"interfacefstarpu__mod_1_1fstarpu__fxt__start__profiling.html":[58,0,0,136],
 "interfacefstarpu__mod_1_1fstarpu__fxt__stop__profiling.html":[59,0,0,137],
+"interfacefstarpu__mod_1_1fstarpu__fxt__stop__profiling.html":[58,0,0,137],
 "interfacefstarpu__mod_1_1fstarpu__fxt__write__data__trace.html":[58,0,0,138],
 "interfacefstarpu__mod_1_1fstarpu__fxt__write__data__trace.html":[59,0,0,138],
 "interfacefstarpu__mod_1_1fstarpu__get__version.html":[58,0,0,139],
 "interfacefstarpu__mod_1_1fstarpu__get__version.html":[59,0,0,139],
-"interfacefstarpu__mod_1_1fstarpu__insert__task.html":[59,0,0,140],
 "interfacefstarpu__mod_1_1fstarpu__insert__task.html":[58,0,0,140],
-"interfacefstarpu__mod_1_1fstarpu__is__paused.html":[59,0,0,141],
+"interfacefstarpu__mod_1_1fstarpu__insert__task.html":[59,0,0,140],
 "interfacefstarpu__mod_1_1fstarpu__is__paused.html":[58,0,0,141],
-"interfacefstarpu__mod_1_1fstarpu__malloc.html":[59,0,0,142],
+"interfacefstarpu__mod_1_1fstarpu__is__paused.html":[59,0,0,141],
 "interfacefstarpu__mod_1_1fstarpu__malloc.html":[58,0,0,142],
+"interfacefstarpu__mod_1_1fstarpu__malloc.html":[59,0,0,142],
 "interfacefstarpu__mod_1_1fstarpu__malloc__on__node.html":[59,0,0,143],
 "interfacefstarpu__mod_1_1fstarpu__malloc__on__node.html":[58,0,0,143],
-"interfacefstarpu__mod_1_1fstarpu__matrix__data__register.html":[59,0,0,144],
 "interfacefstarpu__mod_1_1fstarpu__matrix__data__register.html":[58,0,0,144],
-"interfacefstarpu__mod_1_1fstarpu__matrix__filter__block.html":[59,0,0,145],
+"interfacefstarpu__mod_1_1fstarpu__matrix__data__register.html":[59,0,0,144],
 "interfacefstarpu__mod_1_1fstarpu__matrix__filter__block.html":[58,0,0,145],
-"interfacefstarpu__mod_1_1fstarpu__matrix__filter__block__shadow.html":[59,0,0,146],
+"interfacefstarpu__mod_1_1fstarpu__matrix__filter__block.html":[59,0,0,145],
 "interfacefstarpu__mod_1_1fstarpu__matrix__filter__block__shadow.html":[58,0,0,146],
+"interfacefstarpu__mod_1_1fstarpu__matrix__filter__block__shadow.html":[59,0,0,146],
 "interfacefstarpu__mod_1_1fstarpu__matrix__filter__vertical__block.html":[58,0,0,147],
 "interfacefstarpu__mod_1_1fstarpu__matrix__filter__vertical__block.html":[59,0,0,147],
 "interfacefstarpu__mod_1_1fstarpu__matrix__filter__vertical__block__shadow.html":[59,0,0,148],
@@ -39,18 +40,18 @@ var NAVTREEINDEX13 =
 "interfacefstarpu__mod_1_1fstarpu__matrix__get__ld.html":[58,0,0,149],
 "interfacefstarpu__mod_1_1fstarpu__matrix__get__nx.html":[59,0,0,150],
 "interfacefstarpu__mod_1_1fstarpu__matrix__get__nx.html":[58,0,0,150],
-"interfacefstarpu__mod_1_1fstarpu__matrix__get__ny.html":[59,0,0,151],
 "interfacefstarpu__mod_1_1fstarpu__matrix__get__ny.html":[58,0,0,151],
-"interfacefstarpu__mod_1_1fstarpu__matrix__get__ptr.html":[59,0,0,152],
+"interfacefstarpu__mod_1_1fstarpu__matrix__get__ny.html":[59,0,0,151],
 "interfacefstarpu__mod_1_1fstarpu__matrix__get__ptr.html":[58,0,0,152],
-"interfacefstarpu__mod_1_1fstarpu__matrix__ptr__register.html":[59,0,0,153],
+"interfacefstarpu__mod_1_1fstarpu__matrix__get__ptr.html":[59,0,0,152],
 "interfacefstarpu__mod_1_1fstarpu__matrix__ptr__register.html":[58,0,0,153],
+"interfacefstarpu__mod_1_1fstarpu__matrix__ptr__register.html":[59,0,0,153],
 "interfacefstarpu__mod_1_1fstarpu__memchunk__tidy.html":[59,0,0,154],
 "interfacefstarpu__mod_1_1fstarpu__memchunk__tidy.html":[58,0,0,154],
 "interfacefstarpu__mod_1_1fstarpu__memory__nodes__get__count.html":[59,0,0,155],
 "interfacefstarpu__mod_1_1fstarpu__memory__nodes__get__count.html":[58,0,0,155],
-"interfacefstarpu__mod_1_1fstarpu__memory__pin.html":[58,0,0,156],
 "interfacefstarpu__mod_1_1fstarpu__memory__pin.html":[59,0,0,156],
+"interfacefstarpu__mod_1_1fstarpu__memory__pin.html":[58,0,0,156],
 "interfacefstarpu__mod_1_1fstarpu__memory__unpin.html":[59,0,0,157],
 "interfacefstarpu__mod_1_1fstarpu__memory__unpin.html":[58,0,0,157],
 "interfacefstarpu__mod_1_1fstarpu__opencl__worker__get__count.html":[58,0,0,158],
@@ -61,20 +62,20 @@ var NAVTREEINDEX13 =
 "interfacefstarpu__mod_1_1fstarpu__parallel__task__barrier__init__n__init__n.html":[58,0,0,160],
 "interfacefstarpu__mod_1_1fstarpu__pause.html":[59,0,0,161],
 "interfacefstarpu__mod_1_1fstarpu__pause.html":[58,0,0,161],
-"interfacefstarpu__mod_1_1fstarpu__perfmodel__allocate.html":[58,0,0,162],
 "interfacefstarpu__mod_1_1fstarpu__perfmodel__allocate.html":[59,0,0,162],
-"interfacefstarpu__mod_1_1fstarpu__perfmodel__free.html":[58,0,0,163],
+"interfacefstarpu__mod_1_1fstarpu__perfmodel__allocate.html":[58,0,0,162],
 "interfacefstarpu__mod_1_1fstarpu__perfmodel__free.html":[59,0,0,163],
-"interfacefstarpu__mod_1_1fstarpu__perfmodel__set__symbol.html":[58,0,0,164],
+"interfacefstarpu__mod_1_1fstarpu__perfmodel__free.html":[58,0,0,163],
 "interfacefstarpu__mod_1_1fstarpu__perfmodel__set__symbol.html":[59,0,0,164],
+"interfacefstarpu__mod_1_1fstarpu__perfmodel__set__symbol.html":[58,0,0,164],
 "interfacefstarpu__mod_1_1fstarpu__perfmodel__set__type.html":[59,0,0,165],
 "interfacefstarpu__mod_1_1fstarpu__perfmodel__set__type.html":[58,0,0,165],
-"interfacefstarpu__mod_1_1fstarpu__resume.html":[59,0,0,166],
 "interfacefstarpu__mod_1_1fstarpu__resume.html":[58,0,0,166],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__add__workers.html":[59,0,0,167],
+"interfacefstarpu__mod_1_1fstarpu__resume.html":[59,0,0,166],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__add__workers.html":[58,0,0,167],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__bind__current__thread__to__cpuid.html":[59,0,0,168],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__add__workers.html":[59,0,0,167],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__bind__current__thread__to__cpuid.html":[58,0,0,168],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__bind__current__thread__to__cpuid.html":[59,0,0,168],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__book__workers__for__task.html":[58,0,0,169],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__book__workers__for__task.html":[59,0,0,169],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__call__pushed__task__cb.html":[58,0,0,170],
@@ -83,46 +84,46 @@ var NAVTREEINDEX13 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__type__of__worker.html":[58,0,0,171],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__worker.html":[59,0,0,172],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__worker.html":[58,0,0,172],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__create.html":[58,0,0,173],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__create.html":[59,0,0,173],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__create.html":[58,0,0,173],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__create__inside__interval.html":[59,0,0,174],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__create__inside__interval.html":[58,0,0,174],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete.html":[59,0,0,175],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete.html":[58,0,0,175],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete__worker__collection.html":[59,0,0,176],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete.html":[59,0,0,175],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete__worker__collection.html":[58,0,0,176],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__display__workers.html":[59,0,0,177],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete__worker__collection.html":[59,0,0,176],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__display__workers.html":[58,0,0,177],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__exec__parallel__code.html":[59,0,0,178],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__display__workers.html":[59,0,0,177],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__exec__parallel__code.html":[58,0,0,178],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__exec__parallel__code.html":[59,0,0,178],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__finished__submit.html":[58,0,0,179],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__finished__submit.html":[59,0,0,179],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__context.html":[59,0,0,180],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__context.html":[58,0,0,180],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__ctx__for__task.html":[58,0,0,181],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__context.html":[59,0,0,180],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__ctx__for__task.html":[59,0,0,181],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__hierarchy__level.html":[58,0,0,182],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__ctx__for__task.html":[58,0,0,181],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__hierarchy__level.html":[59,0,0,182],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__hierarchy__level.html":[58,0,0,182],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__inheritor.html":[58,0,0,183],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__inheritor.html":[59,0,0,183],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__max__priority.html":[58,0,0,184],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__max__priority.html":[59,0,0,184],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__min__priority.html":[58,0,0,185],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__max__priority.html":[58,0,0,184],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__min__priority.html":[59,0,0,185],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__min__priority.html":[58,0,0,185],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__flops.html":[58,0,0,186],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__flops.html":[59,0,0,186],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__tasks.html":[58,0,0,187],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__tasks.html":[59,0,0,187],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__tasks.html":[58,0,0,187],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nshared__workers.html":[59,0,0,188],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nshared__workers.html":[58,0,0,188],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nworkers.html":[58,0,0,189],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nworkers.html":[59,0,0,189],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__policy__data.html":[59,0,0,190],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nworkers.html":[58,0,0,189],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__policy__data.html":[58,0,0,190],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__priority.html":[59,0,0,191],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__policy__data.html":[59,0,0,190],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__priority.html":[58,0,0,191],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__user__data.html":[59,0,0,192],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__priority.html":[59,0,0,191],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__user__data.html":[58,0,0,192],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__user__data.html":[59,0,0,192],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__worker__rank.html":[59,0,0,193],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__worker__rank.html":[58,0,0,193],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement.html":[59,0,0,194],
@@ -131,24 +132,24 @@ var NAVTREEINDEX13 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement__all.html":[58,0,0,195],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment.html":[59,0,0,196],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment.html":[58,0,0,196],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment__all.html":[58,0,0,197],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment__all.html":[59,0,0,197],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html":[58,0,0,198],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment__all.html":[58,0,0,197],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html":[59,0,0,198],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset__all.html":[58,0,0,199],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html":[58,0,0,198],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset__all.html":[59,0,0,199],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset__all.html":[58,0,0,199],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__master__get__context.html":[59,0,0,200],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__master__get__context.html":[58,0,0,200],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__max__priority__is__set.html":[58,0,0,201],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__max__priority__is__set.html":[59,0,0,201],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html":[58,0,0,202],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html":[59,0,0,202],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html":[58,0,0,203],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html":[59,0,0,203],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html":[58,0,0,203],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__overlapping__ctxs__on__worker.html":[58,0,0,204],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__overlapping__ctxs__on__worker.html":[59,0,0,204],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[58,0,0,205],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[59,0,0,205],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[58,0,0,205],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html":[58,0,0,206],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html":[59,0,0,206],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html":[58,0,0,207],
@@ -161,8 +162,8 @@ var NAVTREEINDEX13 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html":[59,0,0,210],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__min__priority.html":[58,0,0,211],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__min__priority.html":[59,0,0,211],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__policy__data.html":[59,0,0,212],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__policy__data.html":[58,0,0,212],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__policy__data.html":[59,0,0,212],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__stop__task__submission.html":[59,0,0,213],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__stop__task__submission.html":[58,0,0,213],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__unbook__workers__for__task.html":[59,0,0,214],
@@ -177,40 +178,40 @@ var NAVTREEINDEX13 =
 "interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html":[58,0,0,218],
 "interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[59,0,0,219],
 "interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[58,0,0,219],
-"interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[58,0,0,220],
 "interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[59,0,0,220],
+"interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[58,0,0,220],
 "interfacefstarpu__mod_1_1fstarpu__shutdown.html":[59,0,0,221],
 "interfacefstarpu__mod_1_1fstarpu__shutdown.html":[58,0,0,221],
 "interfacefstarpu__mod_1_1fstarpu__sleep.html":[58,0,0,222],
 "interfacefstarpu__mod_1_1fstarpu__sleep.html":[59,0,0,222],
 "interfacefstarpu__mod_1_1fstarpu__tag__declare__deps__array.html":[58,0,0,223],
 "interfacefstarpu__mod_1_1fstarpu__tag__declare__deps__array.html":[59,0,0,223],
-"interfacefstarpu__mod_1_1fstarpu__tag__get__task.html":[58,0,0,224],
 "interfacefstarpu__mod_1_1fstarpu__tag__get__task.html":[59,0,0,224],
-"interfacefstarpu__mod_1_1fstarpu__tag__notify__from__apps.html":[58,0,0,225],
+"interfacefstarpu__mod_1_1fstarpu__tag__get__task.html":[58,0,0,224],
 "interfacefstarpu__mod_1_1fstarpu__tag__notify__from__apps.html":[59,0,0,225],
-"interfacefstarpu__mod_1_1fstarpu__tag__remove.html":[58,0,0,226],
+"interfacefstarpu__mod_1_1fstarpu__tag__notify__from__apps.html":[58,0,0,225],
 "interfacefstarpu__mod_1_1fstarpu__tag__remove.html":[59,0,0,226],
-"interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[58,0,0,227],
+"interfacefstarpu__mod_1_1fstarpu__tag__remove.html":[58,0,0,226],
 "interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[59,0,0,227],
+"interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[58,0,0,227],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait.html":[58,0,0,228],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait.html":[59,0,0,228],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html":[58,0,0,229],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html":[59,0,0,229],
 "interfacefstarpu__mod_1_1fstarpu__task__clean.html":[58,0,0,230],
 "interfacefstarpu__mod_1_1fstarpu__task__clean.html":[59,0,0,230],
-"interfacefstarpu__mod_1_1fstarpu__task__create.html":[59,0,0,231],
 "interfacefstarpu__mod_1_1fstarpu__task__create.html":[58,0,0,231],
+"interfacefstarpu__mod_1_1fstarpu__task__create.html":[59,0,0,231],
 "interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[59,0,0,232],
 "interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[58,0,0,232],
-"interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[58,0,0,233],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[59,0,0,233],
-"interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[58,0,0,234],
+"interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[58,0,0,233],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[59,0,0,234],
+"interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[58,0,0,234],
 "interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[58,0,0,235],
 "interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[59,0,0,235],
-"interfacefstarpu__mod_1_1fstarpu__task__dup.html":[59,0,0,236],
 "interfacefstarpu__mod_1_1fstarpu__task__dup.html":[58,0,0,236],
+"interfacefstarpu__mod_1_1fstarpu__task__dup.html":[59,0,0,236],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[58,0,0,237],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[59,0,0,237],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[59,0,0,238],
@@ -225,8 +226,8 @@ var NAVTREEINDEX13 =
 "interfacefstarpu__mod_1_1fstarpu__task__init.html":[58,0,0,242],
 "interfacefstarpu__mod_1_1fstarpu__task__insert.html":[59,0,0,243],
 "interfacefstarpu__mod_1_1fstarpu__task__insert.html":[58,0,0,243],
-"interfacefstarpu__mod_1_1fstarpu__task__nready.html":[59,0,0,244],
 "interfacefstarpu__mod_1_1fstarpu__task__nready.html":[58,0,0,244],
+"interfacefstarpu__mod_1_1fstarpu__task__nready.html":[59,0,0,244],
 "interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[58,0,0,245],
 "interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[59,0,0,245],
 "interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[58,0,0,246],
@@ -243,11 +244,10 @@ var NAVTREEINDEX13 =
 "interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[59,0,0,251],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[58,0,0,252],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[59,0,0,252],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[59,0,0,253],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[58,0,0,253],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[59,0,0,253],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[58,0,0,254],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[59,0,0,254],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[59,0,0,255],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[58,0,0,255],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[58,0,0,256]
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[58,0,0,255]
 };
