@@ -1,5 +1,6 @@
 var NAVTREEINDEX6 =
 {
+"group__API__Initialization__and__Termination.html#affd5b335a988c417ecb679d5ecf7c489":[57,0,0,14],
 "group__API__Initialization__and__Termination.html#ga06215a557f489ef2dd936f691e395eb7":[57,0,26],
 "group__API__Initialization__and__Termination.html#ga0702f607811a2af4f7d2bc271eb434e9":[57,0,18],
 "group__API__Initialization__and__Termination.html#ga1913a0c856998a4b74466bb655ea7d49":[57,0,16],
@@ -248,6 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__MPI__Support.html#gaa823d6398e61516bba887b90ad048914":[57,23,83],
 "group__API__MPI__Support.html#gaa83e001c860c2b132fd5b65cfa99d053":[57,23,67],
 "group__API__MPI__Support.html#gaaa286b76a8a60c508f83741bb371f28c":[57,23,46],
-"group__API__MPI__Support.html#gaad03f0a288bad79078045130b9a83188":[57,23,51],
-"group__API__MPI__Support.html#gaaf806ce3131edd757470c7401bd41bd7":[57,23,14]
+"group__API__MPI__Support.html#gaad03f0a288bad79078045130b9a83188":[57,23,51]
 };
