@@ -1,5 +1,7 @@
 var NAVTREEINDEX8 =
 {
+"group__API__OpenMP__Runtime__Support.html#ga1b951f0922d794e6deb2579c81bcf41b":[57,17,54],
+"group__API__OpenMP__Runtime__Support.html#ga2c2739d7b7a1702540b878684b8e4e9b":[57,17,24],
 "group__API__OpenMP__Runtime__Support.html#ga2c980c583e9faf124b4446fa90b5ece9":[57,17,37],
 "group__API__OpenMP__Runtime__Support.html#ga2cb37eec19b8a24242819e666ecea8fc":[57,17,56],
 "group__API__OpenMP__Runtime__Support.html#ga2f1f0d70df3de43bf9069eb4c2e1ca9f":[57,17,15],
@@ -247,7 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__Perf__Steering.html#ga8091cf0aff44776750c353dc78117740":[57,36,5],
 "group__API__Perf__Steering.html#ga818f8dfca1507c1f26c6b716614ced1f":[57,36,2],
 "group__API__Perf__Steering.html#ga8ccc830962c507c32a68b19368015967":[57,36,17],
-"group__API__Perf__Steering.html#ga96203abd0ba972e7fda0e60ec6fbc5bb":[57,36,21],
-"group__API__Perf__Steering.html#ga9715d7c1d761e641fce5c4ec72507d2b":[57,36,37],
-"group__API__Perf__Steering.html#gaa17ede3e783e660a49eca0b93e453d55":[57,36,12]
+"group__API__Perf__Steering.html#ga96203abd0ba972e7fda0e60ec6fbc5bb":[57,36,21]
 };
