@@ -1,5 +1,7 @@
 var NAVTREEINDEX9 =
 {
+"group__API__Perf__Steering.html#ga9715d7c1d761e641fce5c4ec72507d2b":[57,36,37],
+"group__API__Perf__Steering.html#gaa17ede3e783e660a49eca0b93e453d55":[57,36,12],
 "group__API__Perf__Steering.html#gaa3355e070b7f2275deb8616bc3a8bb9b":[57,36,31],
 "group__API__Perf__Steering.html#gaa8f9f7eab09618e42e51577cd0b51486":[57,36,0],
 "group__API__Perf__Steering.html#gab89b75f03facf27313b30c925dc511c5":[57,36,36],
@@ -247,7 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__SC__Hypervisor.html#ga9734466cc2ae6b8fcd280a602ac1cf40":[57,46,25],
 "group__API__SC__Hypervisor.html#ga9968686b96e842b384e2fd2495c8c7ab":[57,46,27],
 "group__API__SC__Hypervisor.html#gaa2299b4916c0e8b3ffe5db762d37d092":[57,46,52],
-"group__API__SC__Hypervisor.html#gaa768d65847bee6f26861217af9437ae2":[57,46,51],
-"group__API__SC__Hypervisor.html#gaafac498199c6441e2d45c9b4eac8dfe4":[57,46,7],
-"group__API__SC__Hypervisor.html#gab02cf89fff4e322e47bc96fb3b60b1ac":[57,46,44]
+"group__API__SC__Hypervisor.html#gaa768d65847bee6f26861217af9437ae2":[57,46,51]
 };
