@@ -1,5 +1,7 @@
 var NAVTREEINDEX6 =
 {
+"group__API__OpenCL__Extensions.html#ga9a1331f26cc54a1f5406770f68b95d29":[5,15,28],
+"group__API__OpenCL__Extensions.html#ga9e0073e4c839eec6096f6eeca21d7e36":[5,15,25],
 "group__API__OpenCL__Extensions.html#gaa38e7cb3231ed30303e50f46c8f6e39c":[5,15,20],
 "group__API__OpenCL__Extensions.html#gab43c1f30361aaa72ca98a9a9fdec792b":[5,15,11],
 "group__API__OpenCL__Extensions.html#gababf3ee0552f34c89fdc8ebdec116dbf":[5,15,2],
@@ -247,7 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__Perf__Monitoring.html#gab6b19fe5667ce4ea447d19d5ed88ae7d":[5,38,20],
 "group__API__Perf__Monitoring.html#gaba3d2e0ac27cf891689bd62805656d5f":[5,38,32],
 "group__API__Perf__Monitoring.html#gac0251242696b1b9c977ce9c73930cbd9":[5,38,9],
-"group__API__Perf__Monitoring.html#gad3a66e71b5a5e3b2e44df2d7326ae73b":[5,38,2],
-"group__API__Perf__Monitoring.html#gad3e6ba0b643d9bd1a3e8920bf0b3dbea":[5,38,17],
-"group__API__Perf__Monitoring.html#gadee4d7d4b66e61fed1cf539b6a4411a8":[5,38,5]
+"group__API__Perf__Monitoring.html#gad3a66e71b5a5e3b2e44df2d7326ae73b":[5,38,2]
 };
