@@ -1,5 +1,7 @@
 var NAVTREEINDEX7 =
 {
+"group__API__Perf__Monitoring.html#gad3e6ba0b643d9bd1a3e8920bf0b3dbea":[5,38,17],
+"group__API__Perf__Monitoring.html#gadee4d7d4b66e61fed1cf539b6a4411a8":[5,38,5],
 "group__API__Perf__Monitoring.html#gae9960277a9e4f22f8000ba34aa6afc42":[5,38,19],
 "group__API__Perf__Monitoring.html#gaf103433df73ec9b645ef73a99dc59bdd":[5,38,27],
 "group__API__Perf__Monitoring.html#gaf41faafb0ddcd54d74a1c7620b670b6d":[5,38,16],
@@ -247,7 +249,5 @@ var NAVTREEINDEX7 =
 "group__API__SC__Hypervisor.html#a79c6a87b792c849cc6c388dbf17d2d49":[5,47,1,4],
 "group__API__SC__Hypervisor.html#a829c79920efa453ee18491e8a85c1ff6":[5,47,3,3],
 "group__API__SC__Hypervisor.html#a838a86b485c9091ab11ea78bfbd12edd":[5,47,2,2],
-"group__API__SC__Hypervisor.html#a9a8cebea8354bedd492764a53037f000":[5,47,2,7],
-"group__API__SC__Hypervisor.html#a9aba37893ddb344de680aa901f686f2d":[5,47,3,1],
-"group__API__SC__Hypervisor.html#ab44752ac4a1d34c397d8fe8b10e8611b":[5,47,2,6]
+"group__API__SC__Hypervisor.html#a9a8cebea8354bedd492764a53037f000":[5,47,2,7]
 };
