@@ -1,5 +1,7 @@
 var NAVTREEINDEX8 =
 {
+"group__API__SC__Hypervisor.html#a9aba37893ddb344de680aa901f686f2d":[5,47,3,1],
+"group__API__SC__Hypervisor.html#ab44752ac4a1d34c397d8fe8b10e8611b":[5,47,2,6],
 "group__API__SC__Hypervisor.html#ac676ac4892a469ad4674b560c2b92514":[5,47,2,10],
 "group__API__SC__Hypervisor.html#ac6da5b817008cd1002fac2412ee1ccde":[5,47,3,2],
 "group__API__SC__Hypervisor.html#ac71dc391218a17c435238f6bc42d2250":[5,47,2,0],
@@ -247,7 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__Standard__Memory__Library.html#ga1456598a362e4ee275247bd1a1d4327b":[5,44,22],
 "group__API__Standard__Memory__Library.html#ga18cb9a696ddb392c6874939c8cffd495":[5,44,20],
 "group__API__Standard__Memory__Library.html#ga2abe959e39acfb75c7c0652706dfe84c":[5,44,0],
-"group__API__Standard__Memory__Library.html#ga3506e4b5ab7a605e25968883ded27d64":[5,44,17],
-"group__API__Standard__Memory__Library.html#ga49603eaea3b05e8ced9ba1bd873070c3":[5,44,10],
-"group__API__Standard__Memory__Library.html#ga4c38ddeaf0bba0226f8a5c2c83cf7ab7":[5,44,27]
+"group__API__Standard__Memory__Library.html#ga3506e4b5ab7a605e25968883ded27d64":[5,44,17]
 };
