@@ -1,5 +1,7 @@
 var NAVTREEINDEX10 =
 {
+"group__API__Workers.html#ga38c0b1858730fec2211991147a964910":[10,18,69],
+"group__API__Workers.html#ga39b7e2b82022313535c7b0015c2a0176":[10,18,45],
 "group__API__Workers.html#ga3a6a9eddecb3e97b3c37e151003ea7c2":[10,18,32],
 "group__API__Workers.html#ga3c4c7e122c29d884fe1674434b69cf52":[10,18,22],
 "group__API__Workers.html#ga3f985e55d355aa7b1c83471230b37a39":[10,18,39],
@@ -77,32 +79,32 @@ var NAVTREEINDEX10 =
 "group__API__Workers.html#structstarpu__sched__ctx__iterator":[10,18,0],
 "group__API__Workers.html#structstarpu__worker__collection":[10,18,1],
 "index.html":[],
-"interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[12,0,0,0],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[11,0,0,0],
-"interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[11,0,0,1],
+"interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[12,0,0,0],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[12,0,0,1],
-"interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[11,0,0,2],
+"interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[11,0,0,1],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[12,0,0,2],
-"interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[11,0,0,3],
+"interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[11,0,0,2],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[12,0,0,3],
+"interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[11,0,0,3],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[12,0,0,4],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[11,0,0,4],
 "interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[12,0,0,5],
 "interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[11,0,0,5],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[12,0,0,6],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[11,0,0,6],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[11,0,0,7],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[12,0,0,7],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[12,0,0,8],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[11,0,0,7],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[11,0,0,8],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[12,0,0,9],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[12,0,0,8],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[11,0,0,9],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[12,0,0,10],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[12,0,0,9],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[11,0,0,10],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[12,0,0,10],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[12,0,0,11],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[11,0,0,11],
-"interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[11,0,0,12],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[12,0,0,12],
+"interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[11,0,0,12],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[11,0,0,13],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[12,0,0,13],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[11,0,0,14],
@@ -119,12 +121,12 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[12,0,0,19],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[11,0,0,20],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[12,0,0,20],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[12,0,0,21],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[11,0,0,21],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[12,0,0,21],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[11,0,0,22],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[12,0,0,22],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[12,0,0,23],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[11,0,0,23],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[12,0,0,23],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[11,0,0,24],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[12,0,0,24],
 "interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[11,0,0,25],
@@ -135,88 +137,88 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[12,0,0,27],
 "interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[11,0,0,28],
 "interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[12,0,0,28],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[12,0,0,29],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[11,0,0,29],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[11,0,0,30],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[12,0,0,29],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[12,0,0,30],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[11,0,0,31],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[11,0,0,30],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[12,0,0,31],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[11,0,0,31],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[11,0,0,32],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[12,0,0,32],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[11,0,0,33],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[12,0,0,33],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[12,0,0,34],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[11,0,0,34],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[12,0,0,35],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[12,0,0,34],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[11,0,0,35],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[12,0,0,36],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[12,0,0,35],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[11,0,0,36],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[12,0,0,36],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[12,0,0,37],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[11,0,0,37],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[12,0,0,38],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[11,0,0,38],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[12,0,0,38],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html":[12,0,0,39],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html":[11,0,0,39],
-"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html":[11,0,0,40],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html":[12,0,0,40],
+"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html":[11,0,0,40],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__rank.html":[12,0,0,41],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__rank.html":[11,0,0,41],
-"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__size.html":[11,0,0,42],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__size.html":[12,0,0,42],
+"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__size.html":[11,0,0,42],
 "interfacefstarpu__mod_1_1fstarpu__conf__allocate.html":[12,0,0,43],
 "interfacefstarpu__mod_1_1fstarpu__conf__allocate.html":[11,0,0,43],
 "interfacefstarpu__mod_1_1fstarpu__conf__free.html":[11,0,0,44],
 "interfacefstarpu__mod_1_1fstarpu__conf__free.html":[12,0,0,44],
-"interfacefstarpu__mod_1_1fstarpu__conf__init.html":[12,0,0,45],
 "interfacefstarpu__mod_1_1fstarpu__conf__init.html":[11,0,0,45],
-"interfacefstarpu__mod_1_1fstarpu__conf__set__max__prio.html":[11,0,0,46],
+"interfacefstarpu__mod_1_1fstarpu__conf__init.html":[12,0,0,45],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__max__prio.html":[12,0,0,46],
-"interfacefstarpu__mod_1_1fstarpu__conf__set__min__prio.html":[12,0,0,47],
+"interfacefstarpu__mod_1_1fstarpu__conf__set__max__prio.html":[11,0,0,46],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__min__prio.html":[11,0,0,47],
+"interfacefstarpu__mod_1_1fstarpu__conf__set__min__prio.html":[12,0,0,47],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__ncpu.html":[12,0,0,48],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__ncpu.html":[11,0,0,48],
-"interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[11,0,0,49],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[12,0,0,49],
-"interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html":[11,0,0,50],
+"interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[11,0,0,49],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html":[12,0,0,50],
-"interfacefstarpu__mod_1_1fstarpu__conf__set__sched__policy__name.html":[11,0,0,51],
+"interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html":[11,0,0,50],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__sched__policy__name.html":[12,0,0,51],
+"interfacefstarpu__mod_1_1fstarpu__conf__set__sched__policy__name.html":[11,0,0,51],
 "interfacefstarpu__mod_1_1fstarpu__cpu__worker__get__count.html":[12,0,0,52],
 "interfacefstarpu__mod_1_1fstarpu__cpu__worker__get__count.html":[11,0,0,52],
 "interfacefstarpu__mod_1_1fstarpu__create__sync__task.html":[12,0,0,53],
 "interfacefstarpu__mod_1_1fstarpu__create__sync__task.html":[11,0,0,53],
 "interfacefstarpu__mod_1_1fstarpu__cublas__init.html":[11,0,0,54],
 "interfacefstarpu__mod_1_1fstarpu__cublas__init.html":[12,0,0,54],
-"interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[12,0,0,55],
 "interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[11,0,0,55],
+"interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[12,0,0,55],
 "interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[12,0,0,56],
 "interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[11,0,0,56],
 "interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[12,0,0,57],
 "interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[11,0,0,57],
-"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[12,0,0,58],
 "interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[11,0,0,58],
+"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[12,0,0,58],
 "interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[12,0,0,59],
 "interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[11,0,0,59],
-"interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[12,0,0,60],
 "interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[11,0,0,60],
-"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[11,0,0,61],
+"interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[12,0,0,60],
 "interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[12,0,0,61],
-"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[11,0,0,62],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[11,0,0,61],
 "interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[12,0,0,62],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[11,0,0,63],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[11,0,0,62],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[12,0,0,63],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[11,0,0,64],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[11,0,0,63],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[12,0,0,64],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[11,0,0,64],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[11,0,0,65],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[12,0,0,65],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[11,0,0,66],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[12,0,0,66],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[12,0,0,67],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[11,0,0,67],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[12,0,0,67],
 "interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[11,0,0,68],
 "interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[12,0,0,68],
-"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[12,0,0,69],
 "interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[11,0,0,69],
+"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[12,0,0,69],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[12,0,0,70],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[11,0,0,70],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[12,0,0,71],
@@ -225,14 +227,14 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[11,0,0,72],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[12,0,0,73],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[11,0,0,73],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[11,0,0,74],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[12,0,0,74],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[11,0,0,75],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[11,0,0,74],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[12,0,0,75],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[11,0,0,75],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[12,0,0,76],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[11,0,0,76],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[12,0,0,77],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[11,0,0,77],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[12,0,0,77],
 "interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[11,0,0,78],
 "interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[12,0,0,78],
 "interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[11,0,0,79],
@@ -241,13 +243,11 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[12,0,0,80],
 "interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[11,0,0,81],
 "interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[12,0,0,81],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[12,0,0,82],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[11,0,0,82],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[12,0,0,83],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[12,0,0,82],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[11,0,0,83],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[12,0,0,83],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[12,0,0,84],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[11,0,0,84],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[12,0,0,85],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[11,0,0,85],
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[11,0,0,86]
+"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[12,0,0,85]
 };
