@@ -1,6 +1,8 @@
 var NAVTREEINDEX11 =
 {
+"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[11,0,0,85],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[12,0,0,86],
+"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[11,0,0,86],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[12,0,0,87],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[11,0,0,87],
 "interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[11,0,0,88],
@@ -11,40 +13,40 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[11,0,0,90],
 "interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[12,0,0,91],
 "interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[11,0,0,91],
-"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[11,0,0,92],
 "interfacefstarpu__mod_1_1fstarpu__data__partition.html":[12,0,0,92],
+"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[11,0,0,92],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[12,0,0,93],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[11,0,0,93],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[12,0,0,94],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[11,0,0,94],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[11,0,0,95],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[12,0,0,95],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[11,0,0,96],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[11,0,0,95],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[12,0,0,96],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[11,0,0,97],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[11,0,0,96],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[12,0,0,97],
-"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[11,0,0,98],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[11,0,0,97],
 "interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[12,0,0,98],
-"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[11,0,0,99],
+"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[11,0,0,98],
 "interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[12,0,0,99],
+"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[11,0,0,99],
 "interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[11,0,0,100],
 "interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[12,0,0,100],
 "interfacefstarpu__mod_1_1fstarpu__data__release.html":[11,0,0,101],
 "interfacefstarpu__mod_1_1fstarpu__data__release.html":[12,0,0,101],
 "interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[11,0,0,102],
 "interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[12,0,0,102],
-"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[11,0,0,103],
 "interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[12,0,0,103],
+"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[11,0,0,103],
 "interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html":[11,0,0,104],
 "interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html":[12,0,0,104],
 "interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods__with__args.html":[11,0,0,105],
 "interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods__with__args.html":[12,0,0,105],
 "interfacefstarpu__mod_1_1fstarpu__data__test__if__allocated__on__node.html":[11,0,0,106],
 "interfacefstarpu__mod_1_1fstarpu__data__test__if__allocated__on__node.html":[12,0,0,106],
-"interfacefstarpu__mod_1_1fstarpu__data__unpartition.html":[12,0,0,107],
 "interfacefstarpu__mod_1_1fstarpu__data__unpartition.html":[11,0,0,107],
-"interfacefstarpu__mod_1_1fstarpu__data__unpartition__readonly__submit.html":[12,0,0,108],
+"interfacefstarpu__mod_1_1fstarpu__data__unpartition.html":[12,0,0,107],
 "interfacefstarpu__mod_1_1fstarpu__data__unpartition__readonly__submit.html":[11,0,0,108],
+"interfacefstarpu__mod_1_1fstarpu__data__unpartition__readonly__submit.html":[12,0,0,108],
 "interfacefstarpu__mod_1_1fstarpu__data__unpartition__submit.html":[11,0,0,109],
 "interfacefstarpu__mod_1_1fstarpu__data__unpartition__submit.html":[12,0,0,109],
 "interfacefstarpu__mod_1_1fstarpu__data__unregister.html":[11,0,0,110],
@@ -73,12 +75,12 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block__shadow.html":[12,0,0,121],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block.html":[11,0,0,122],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block.html":[12,0,0,122],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block__shadow.html":[12,0,0,123],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block__shadow.html":[11,0,0,123],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block.html":[11,0,0,124],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block__shadow.html":[12,0,0,123],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block.html":[12,0,0,124],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block__shadow.html":[12,0,0,125],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block.html":[11,0,0,124],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block__shadow.html":[11,0,0,125],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block__shadow.html":[12,0,0,125],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__divide__in__2.html":[12,0,0,126],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__divide__in__2.html":[11,0,0,126],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__list.html":[12,0,0,127],
@@ -101,8 +103,8 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__fxt__options__init.html":[11,0,0,135],
 "interfacefstarpu__mod_1_1fstarpu__fxt__start__profiling.html":[12,0,0,136],
 "interfacefstarpu__mod_1_1fstarpu__fxt__start__profiling.html":[11,0,0,136],
-"interfacefstarpu__mod_1_1fstarpu__fxt__stop__profiling.html":[11,0,0,137],
 "interfacefstarpu__mod_1_1fstarpu__fxt__stop__profiling.html":[12,0,0,137],
+"interfacefstarpu__mod_1_1fstarpu__fxt__stop__profiling.html":[11,0,0,137],
 "interfacefstarpu__mod_1_1fstarpu__fxt__write__data__trace.html":[11,0,0,138],
 "interfacefstarpu__mod_1_1fstarpu__fxt__write__data__trace.html":[12,0,0,138],
 "interfacefstarpu__mod_1_1fstarpu__get__version.html":[11,0,0,139],
@@ -157,10 +159,10 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__perfmodel__free.html":[11,0,0,163],
 "interfacefstarpu__mod_1_1fstarpu__perfmodel__set__symbol.html":[12,0,0,164],
 "interfacefstarpu__mod_1_1fstarpu__perfmodel__set__symbol.html":[11,0,0,164],
-"interfacefstarpu__mod_1_1fstarpu__perfmodel__set__type.html":[12,0,0,165],
 "interfacefstarpu__mod_1_1fstarpu__perfmodel__set__type.html":[11,0,0,165],
-"interfacefstarpu__mod_1_1fstarpu__resume.html":[12,0,0,166],
+"interfacefstarpu__mod_1_1fstarpu__perfmodel__set__type.html":[12,0,0,165],
 "interfacefstarpu__mod_1_1fstarpu__resume.html":[11,0,0,166],
+"interfacefstarpu__mod_1_1fstarpu__resume.html":[12,0,0,166],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__add__workers.html":[11,0,0,167],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__add__workers.html":[12,0,0,167],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__bind__current__thread__to__cpuid.html":[11,0,0,168],
@@ -173,56 +175,56 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__type__of__worker.html":[12,0,0,171],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__worker.html":[12,0,0,172],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__worker.html":[11,0,0,172],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__create.html":[12,0,0,173],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__create.html":[11,0,0,173],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__create.html":[12,0,0,173],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__create__inside__interval.html":[12,0,0,174],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__create__inside__interval.html":[11,0,0,174],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete.html":[12,0,0,175],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete.html":[11,0,0,175],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete__worker__collection.html":[12,0,0,176],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete__worker__collection.html":[11,0,0,176],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__display__workers.html":[11,0,0,177],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__display__workers.html":[12,0,0,177],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__display__workers.html":[11,0,0,177],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__exec__parallel__code.html":[12,0,0,178],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__exec__parallel__code.html":[11,0,0,178],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__finished__submit.html":[12,0,0,179],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__finished__submit.html":[11,0,0,179],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__context.html":[11,0,0,180],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__finished__submit.html":[12,0,0,179],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__context.html":[12,0,0,180],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__context.html":[11,0,0,180],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__ctx__for__task.html":[12,0,0,181],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__ctx__for__task.html":[11,0,0,181],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__hierarchy__level.html":[11,0,0,182],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__hierarchy__level.html":[12,0,0,182],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__inheritor.html":[12,0,0,183],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__inheritor.html":[11,0,0,183],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__max__priority.html":[12,0,0,184],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__max__priority.html":[11,0,0,184],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__max__priority.html":[12,0,0,184],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__min__priority.html":[12,0,0,185],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__min__priority.html":[11,0,0,185],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__flops.html":[12,0,0,186],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__flops.html":[11,0,0,186],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__tasks.html":[12,0,0,187],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__tasks.html":[11,0,0,187],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nshared__workers.html":[12,0,0,188],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nshared__workers.html":[11,0,0,188],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nshared__workers.html":[12,0,0,188],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nworkers.html":[12,0,0,189],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nworkers.html":[11,0,0,189],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__policy__data.html":[11,0,0,190],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__policy__data.html":[12,0,0,190],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__priority.html":[12,0,0,191],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__priority.html":[11,0,0,191],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__user__data.html":[11,0,0,192],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__priority.html":[12,0,0,191],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__user__data.html":[12,0,0,192],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__worker__rank.html":[12,0,0,193],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__user__data.html":[11,0,0,192],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__worker__rank.html":[11,0,0,193],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement.html":[12,0,0,194],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__worker__rank.html":[12,0,0,193],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement.html":[11,0,0,194],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement__all.html":[12,0,0,195],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement.html":[12,0,0,194],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement__all.html":[11,0,0,195],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement__all.html":[12,0,0,195],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment.html":[12,0,0,196],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment.html":[11,0,0,196],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment__all.html":[12,0,0,197],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment__all.html":[11,0,0,197],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment__all.html":[12,0,0,197],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html":[11,0,0,198],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html":[12,0,0,198],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset__all.html":[11,0,0,199],
@@ -231,23 +233,21 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__master__get__context.html":[12,0,0,200],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__max__priority__is__set.html":[11,0,0,201],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__max__priority__is__set.html":[12,0,0,201],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html":[12,0,0,202],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html":[11,0,0,202],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html":[12,0,0,202],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html":[12,0,0,203],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html":[11,0,0,203],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__overlapping__ctxs__on__worker.html":[11,0,0,204],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__overlapping__ctxs__on__worker.html":[12,0,0,204],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[12,0,0,205],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[11,0,0,205],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[12,0,0,205],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html":[11,0,0,206],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html":[12,0,0,206],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html":[11,0,0,207],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html":[12,0,0,207],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__context.html":[11,0,0,208],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__context.html":[12,0,0,208],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__inheritor.html":[12,0,0,209],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__inheritor.html":[11,0,0,209],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html":[12,0,0,210],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html":[11,0,0,210],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__min__priority.html":[12,0,0,211]
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__inheritor.html":[12,0,0,209],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html":[12,0,0,210]
 };
