@@ -1,5 +1,7 @@
 var NAVTREEINDEX7 =
 {
+"group__API__Parallel__Worker.html#ga6418a1fed34b32217d66860cbf8fc200":[10,37,24],
+"group__API__Parallel__Worker.html#ga6cd34b24aaea1b26df96b7aff9238759":[10,37,22],
 "group__API__Parallel__Worker.html#ga6dc4b6d66ef90b7927559c9e2728a84b":[10,37,21],
 "group__API__Parallel__Worker.html#ga6e2258c377e3aa838c2120904bf96f99":[10,37,34],
 "group__API__Parallel__Worker.html#ga718ac3b3060472256eceb68147a112b9":[10,37,26],
@@ -247,7 +249,5 @@ var NAVTREEINDEX7 =
 "group__API__Profiling.html#ade189cd6175d789db1eb6bfad19b3e35":[10,40,0,8],
 "group__API__Profiling.html#aec88f33a8b4777727d80296c16d85f24":[10,40,0,14],
 "group__API__Profiling.html#aed6a8be9b919f03e093912bfc44c5559":[10,40,1,0],
-"group__API__Profiling.html#ga1e388939370daaf139c73678e413f00a":[10,40,3],
-"group__API__Profiling.html#ga4e4f9fb593d29219a1109062ba9d72ef":[10,40,22],
-"group__API__Profiling.html#ga6511f50290edcabbdf605a1b74746645":[10,40,21]
+"group__API__Profiling.html#ga1e388939370daaf139c73678e413f00a":[10,40,3]
 };
