@@ -1,5 +1,7 @@
 var NAVTREEINDEX8 =
 {
+"group__API__Profiling.html#ga4e4f9fb593d29219a1109062ba9d72ef":[10,40,22],
+"group__API__Profiling.html#ga6511f50290edcabbdf605a1b74746645":[10,40,21],
 "group__API__Profiling.html#ga6ab0a1e4a8a55e0c54e2151fd0a82a36":[10,40,5],
 "group__API__Profiling.html#ga76ad19fc8b99bcd42d505c76aafae6b6":[10,40,18],
 "group__API__Profiling.html#ga7c70803a54aa1e5b463ebb19110c4aa2":[10,40,11],
@@ -247,7 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__Scheduling__Policy.html#a81af53e5f8e59cb12d6d0b378c4b5268":[10,24,0,12],
 "group__API__Scheduling__Policy.html#a84231c0bc118e91e49b0614c24b9de4a":[10,24,0,4],
 "group__API__Scheduling__Policy.html#a9020a364719389cd19c31a657c938293":[10,24,0,10],
-"group__API__Scheduling__Policy.html#ace93b3c465e39c7e2ca894406905dc2a":[10,24,0,0],
-"group__API__Scheduling__Policy.html#ad720f2cd2155e8baa10f57792b68a5eb":[10,24,0,8],
-"group__API__Scheduling__Policy.html#afd00e4e0a058e043c3d8edf916ace4f7":[10,24,0,7]
+"group__API__Scheduling__Policy.html#ace93b3c465e39c7e2ca894406905dc2a":[10,24,0,0]
 };
