@@ -1,5 +1,7 @@
 var NAVTREEINDEX9 =
 {
+"group__API__Scheduling__Policy.html#ad720f2cd2155e8baa10f57792b68a5eb":[10,24,0,8],
+"group__API__Scheduling__Policy.html#afd00e4e0a058e043c3d8edf916ace4f7":[10,24,0,7],
 "group__API__Scheduling__Policy.html#ga1e159d56ffa2d7705bdfd1ceb93e0d64":[10,24,36],
 "group__API__Scheduling__Policy.html#ga20525c5d674b32a9f64fbc9e23c5f55f":[10,24,23],
 "group__API__Scheduling__Policy.html#ga21385d19bc75a7581e774bd455c70790":[10,24,28],
@@ -247,7 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__Workers.html#ga2b75b2600f85996e943ece2631971c62":[10,18,13],
 "group__API__Workers.html#ga2c930d982bacf4bf4dce015ab2d61123":[10,18,66],
 "group__API__Workers.html#ga35c8908fd60c0407901872b25a8a88da":[10,18,68],
-"group__API__Workers.html#ga389142e108345483dc8c0bf07465263c":[10,18,49],
-"group__API__Workers.html#ga38c0b1858730fec2211991147a964910":[10,18,69],
-"group__API__Workers.html#ga39b7e2b82022313535c7b0015c2a0176":[10,18,45]
+"group__API__Workers.html#ga389142e108345483dc8c0bf07465263c":[10,18,49]
 };
