@@ -266,16 +266,16 @@ var NAVTREEINDEX =
 "group__API__Codelet__And__Tasks.html#gga0088c4ab87a08b3e7a375c1a79e91202a5ee20d5e9ae6d031161f7d601f5c44ee",
 "group__API__Data__Interfaces.html#ga7e3ef9efbc7a65adad27f9ac27493493",
 "group__API__Data__Partition.html#ga46d2b144a7de2e17d17b1383ef5f522d",
-"group__API__Insert__Task.html#ga502e5ec7928054775798a57a930bb12b",
-"group__API__Miscellaneous__Helpers.html#ga090e97b588f83718c19f0ed3d07d1d70",
-"group__API__OpenMP__Runtime__Support.html#gaac482422d2b9bc26c1877f49eaa5fca2",
-"group__API__Performance__Model.html#aa82fae955253d333733d34fe4a44e298",
-"group__API__SC__Hypervisor__usage.html#ga6398be50d801f0fc5ad73506e392d476",
-"group__API__Threads.html#ga670ae411d7536934d784c88c6d11177c",
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html",
-"interfacefstarpu__mod_1_1fstarpu__parallel__task__barrier__init__n__init__n.html",
-"interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html",
-"starpu__rand_8h_source.html"
+"group__API__Insert__Task.html#ga4c7656d210572e4fa1860c290af2acfb",
+"group__API__Miscellaneous__Helpers.html",
+"group__API__OpenMP__Runtime__Support.html#gaa63576df9729394a3d53137d7021bab5",
+"group__API__Performance__Model.html#aa22dc6b2674ed810366dc300f4abd7cc",
+"group__API__SC__Hypervisor__usage.html#ga5f2b33a41a697759ee2a222e623f723c",
+"group__API__Threads.html#ga629152a86070cd58811fa17506f7995e",
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html",
+"interfacefstarpu__mod_1_1fstarpu__parallel__task__barrier__init__init.html",
+"interfacefstarpu__mod_1_1fstarpu__void__data__register.html",
+"starpu__profiling__tool_8h_source.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
