@@ -1,5 +1,7 @@
 var NAVTREEINDEX10 =
 {
+"group__API__Threads.html#ga629152a86070cd58811fa17506f7995e":[25,3,12],
+"group__API__Threads.html#ga654b486b4161002221a75cc619eabe48":[25,3,30],
 "group__API__Threads.html#ga670ae411d7536934d784c88c6d11177c":[25,3,28],
 "group__API__Threads.html#ga707b1afc766917d4ddbbe19e5569359b":[25,3,23],
 "group__API__Threads.html#ga7cf8cbee2a33b4714cf37724f657bd4a":[25,3,15],
@@ -182,72 +184,70 @@ var NAVTREEINDEX10 =
 "index.html":[],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[26,0,0,0],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[27,0,0,0],
-"interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[27,0,0,1],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[26,0,0,1],
-"interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[27,0,0,2],
+"interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[27,0,0,1],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[26,0,0,2],
+"interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[27,0,0,2],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[27,0,0,3],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[26,0,0,3],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[27,0,0,4],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[26,0,0,4],
-"interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[26,0,0,5],
 "interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[27,0,0,5],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[27,0,0,6],
+"interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[26,0,0,5],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[26,0,0,6],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[27,0,0,7],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[27,0,0,6],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[26,0,0,7],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[27,0,0,7],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[26,0,0,8],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[27,0,0,8],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[27,0,0,9],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[26,0,0,9],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[27,0,0,10],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[27,0,0,9],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[26,0,0,10],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[27,0,0,10],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[26,0,0,11],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[27,0,0,11],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[26,0,0,12],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[27,0,0,12],
-"interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[26,0,0,13],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[27,0,0,13],
-"interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[26,0,0,14],
+"interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[26,0,0,13],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[27,0,0,14],
-"interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[26,0,0,15],
+"interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[26,0,0,14],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[27,0,0,15],
-"interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[26,0,0,16],
+"interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[26,0,0,15],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[27,0,0,16],
+"interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[26,0,0,16],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[26,0,0,17],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[27,0,0,17],
 "interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[26,0,0,18],
 "interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[27,0,0,18],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[27,0,0,19],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[26,0,0,19],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[27,0,0,19],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[26,0,0,20],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[27,0,0,20],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[27,0,0,21],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[26,0,0,21],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[27,0,0,22],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[27,0,0,21],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[26,0,0,22],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[27,0,0,22],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[26,0,0,23],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[27,0,0,23],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[27,0,0,24],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[26,0,0,24],
-"interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[27,0,0,25],
 "interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[26,0,0,25],
-"interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html":[27,0,0,26],
+"interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[27,0,0,25],
 "interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html":[26,0,0,26],
-"interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[27,0,0,27],
+"interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html":[27,0,0,26],
 "interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[26,0,0,27],
-"interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[27,0,0,28],
+"interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[27,0,0,27],
 "interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[26,0,0,28],
+"interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[27,0,0,28],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[26,0,0,29],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[27,0,0,29],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[27,0,0,30],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[26,0,0,30],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[27,0,0,31],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[27,0,0,30],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[26,0,0,31],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[27,0,0,32],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[27,0,0,31],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[26,0,0,32],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[27,0,0,32],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[27,0,0,33],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[26,0,0,33],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[26,0,0,34],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[27,0,0,34]
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[26,0,0,33]
 };
