@@ -1,5 +1,7 @@
 var NAVTREEINDEX12 =
 {
+"interfacefstarpu__mod_1_1fstarpu__parallel__task__barrier__init__init.html":[27,0,0,159],
+"interfacefstarpu__mod_1_1fstarpu__parallel__task__barrier__init__init.html":[26,0,0,159],
 "interfacefstarpu__mod_1_1fstarpu__parallel__task__barrier__init__n__init__n.html":[26,0,0,160],
 "interfacefstarpu__mod_1_1fstarpu__parallel__task__barrier__init__n__init__n.html":[27,0,0,160],
 "interfacefstarpu__mod_1_1fstarpu__pause.html":[26,0,0,161],
@@ -18,32 +20,32 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__add__workers.html":[27,0,0,167],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__bind__current__thread__to__cpuid.html":[27,0,0,168],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__bind__current__thread__to__cpuid.html":[26,0,0,168],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__book__workers__for__task.html":[26,0,0,169],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__book__workers__for__task.html":[27,0,0,169],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__book__workers__for__task.html":[26,0,0,169],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__call__pushed__task__cb.html":[26,0,0,170],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__call__pushed__task__cb.html":[27,0,0,170],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__type__of__worker.html":[26,0,0,171],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__type__of__worker.html":[27,0,0,171],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__type__of__worker.html":[26,0,0,171],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__worker.html":[26,0,0,172],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__worker.html":[27,0,0,172],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__create.html":[26,0,0,173],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__create.html":[27,0,0,173],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__create__inside__interval.html":[27,0,0,174],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__create__inside__interval.html":[26,0,0,174],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__create__inside__interval.html":[27,0,0,174],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete.html":[26,0,0,175],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete.html":[27,0,0,175],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete__worker__collection.html":[27,0,0,176],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete__worker__collection.html":[26,0,0,176],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__display__workers.html":[27,0,0,177],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete__worker__collection.html":[27,0,0,176],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__display__workers.html":[26,0,0,177],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__exec__parallel__code.html":[27,0,0,178],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__display__workers.html":[27,0,0,177],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__exec__parallel__code.html":[26,0,0,178],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__finished__submit.html":[27,0,0,179],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__exec__parallel__code.html":[27,0,0,178],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__finished__submit.html":[26,0,0,179],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__context.html":[26,0,0,180],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__finished__submit.html":[27,0,0,179],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__context.html":[27,0,0,180],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__ctx__for__task.html":[26,0,0,181],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__context.html":[26,0,0,180],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__ctx__for__task.html":[27,0,0,181],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__ctx__for__task.html":[26,0,0,181],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__hierarchy__level.html":[27,0,0,182],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__hierarchy__level.html":[26,0,0,182],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__inheritor.html":[27,0,0,183],
@@ -62,40 +64,40 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nworkers.html":[26,0,0,189],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__policy__data.html":[27,0,0,190],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__policy__data.html":[26,0,0,190],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__priority.html":[26,0,0,191],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__priority.html":[27,0,0,191],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__user__data.html":[26,0,0,192],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__priority.html":[26,0,0,191],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__user__data.html":[27,0,0,192],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__worker__rank.html":[26,0,0,193],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__user__data.html":[26,0,0,192],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__worker__rank.html":[27,0,0,193],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement.html":[26,0,0,194],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__worker__rank.html":[26,0,0,193],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement.html":[27,0,0,194],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement__all.html":[26,0,0,195],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement.html":[26,0,0,194],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement__all.html":[27,0,0,195],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment.html":[26,0,0,196],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement__all.html":[26,0,0,195],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment.html":[27,0,0,196],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment__all.html":[26,0,0,197],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment.html":[26,0,0,196],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment__all.html":[27,0,0,197],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html":[26,0,0,198],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment__all.html":[26,0,0,197],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html":[27,0,0,198],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html":[26,0,0,198],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset__all.html":[26,0,0,199],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset__all.html":[27,0,0,199],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__master__get__context.html":[26,0,0,200],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__master__get__context.html":[27,0,0,200],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__max__priority__is__set.html":[27,0,0,201],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__master__get__context.html":[26,0,0,200],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__max__priority__is__set.html":[26,0,0,201],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__max__priority__is__set.html":[27,0,0,201],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html":[26,0,0,202],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html":[27,0,0,202],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html":[27,0,0,203],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html":[26,0,0,203],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__overlapping__ctxs__on__worker.html":[27,0,0,204],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html":[27,0,0,203],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__overlapping__ctxs__on__worker.html":[26,0,0,204],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[27,0,0,205],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__overlapping__ctxs__on__worker.html":[27,0,0,204],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[26,0,0,205],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[27,0,0,205],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html":[26,0,0,206],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html":[27,0,0,206],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html":[26,0,0,207],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html":[27,0,0,207],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html":[26,0,0,207],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__context.html":[26,0,0,208],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__context.html":[27,0,0,208],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__inheritor.html":[26,0,0,209],
@@ -106,54 +108,54 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__min__priority.html":[27,0,0,211],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__policy__data.html":[26,0,0,212],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__policy__data.html":[27,0,0,212],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__stop__task__submission.html":[27,0,0,213],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__stop__task__submission.html":[26,0,0,213],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__unbook__workers__for__task.html":[27,0,0,214],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__stop__task__submission.html":[27,0,0,213],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__unbook__workers__for__task.html":[26,0,0,214],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__unbook__workers__for__task.html":[27,0,0,214],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__get__id.html":[26,0,0,215],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__get__id.html":[27,0,0,215],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__is__master__for__child__ctx.html":[27,0,0,216],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__is__master__for__child__ctx.html":[26,0,0,216],
-"interfacefstarpu__mod_1_1fstarpu__sched__get__max__priority.html":[26,0,0,217],
 "interfacefstarpu__mod_1_1fstarpu__sched__get__max__priority.html":[27,0,0,217],
-"interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html":[26,0,0,218],
+"interfacefstarpu__mod_1_1fstarpu__sched__get__max__priority.html":[26,0,0,217],
 "interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html":[27,0,0,218],
-"interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[26,0,0,219],
+"interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html":[26,0,0,218],
 "interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[27,0,0,219],
-"interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[26,0,0,220],
+"interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[26,0,0,219],
 "interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[27,0,0,220],
-"interfacefstarpu__mod_1_1fstarpu__shutdown.html":[26,0,0,221],
+"interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[26,0,0,220],
 "interfacefstarpu__mod_1_1fstarpu__shutdown.html":[27,0,0,221],
-"interfacefstarpu__mod_1_1fstarpu__sleep.html":[26,0,0,222],
+"interfacefstarpu__mod_1_1fstarpu__shutdown.html":[26,0,0,221],
 "interfacefstarpu__mod_1_1fstarpu__sleep.html":[27,0,0,222],
+"interfacefstarpu__mod_1_1fstarpu__sleep.html":[26,0,0,222],
 "interfacefstarpu__mod_1_1fstarpu__tag__declare__deps__array.html":[27,0,0,223],
 "interfacefstarpu__mod_1_1fstarpu__tag__declare__deps__array.html":[26,0,0,223],
 "interfacefstarpu__mod_1_1fstarpu__tag__get__task.html":[27,0,0,224],
 "interfacefstarpu__mod_1_1fstarpu__tag__get__task.html":[26,0,0,224],
-"interfacefstarpu__mod_1_1fstarpu__tag__notify__from__apps.html":[27,0,0,225],
 "interfacefstarpu__mod_1_1fstarpu__tag__notify__from__apps.html":[26,0,0,225],
-"interfacefstarpu__mod_1_1fstarpu__tag__remove.html":[27,0,0,226],
+"interfacefstarpu__mod_1_1fstarpu__tag__notify__from__apps.html":[27,0,0,225],
 "interfacefstarpu__mod_1_1fstarpu__tag__remove.html":[26,0,0,226],
-"interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[27,0,0,227],
+"interfacefstarpu__mod_1_1fstarpu__tag__remove.html":[27,0,0,226],
 "interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[26,0,0,227],
+"interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[27,0,0,227],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait.html":[26,0,0,228],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait.html":[27,0,0,228],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html":[26,0,0,229],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html":[27,0,0,229],
 "interfacefstarpu__mod_1_1fstarpu__task__clean.html":[26,0,0,230],
 "interfacefstarpu__mod_1_1fstarpu__task__clean.html":[27,0,0,230],
-"interfacefstarpu__mod_1_1fstarpu__task__create.html":[27,0,0,231],
 "interfacefstarpu__mod_1_1fstarpu__task__create.html":[26,0,0,231],
-"interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[26,0,0,232],
+"interfacefstarpu__mod_1_1fstarpu__task__create.html":[27,0,0,231],
 "interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[27,0,0,232],
-"interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[27,0,0,233],
+"interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[26,0,0,232],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[26,0,0,233],
+"interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[27,0,0,233],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[27,0,0,234],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[26,0,0,234],
 "interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[27,0,0,235],
 "interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[26,0,0,235],
-"interfacefstarpu__mod_1_1fstarpu__task__dup.html":[27,0,0,236],
 "interfacefstarpu__mod_1_1fstarpu__task__dup.html":[26,0,0,236],
+"interfacefstarpu__mod_1_1fstarpu__task__dup.html":[27,0,0,236],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[26,0,0,237],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[27,0,0,237],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[27,0,0,238],
@@ -162,62 +164,62 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__task__finished.html":[26,0,0,239],
 "interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[26,0,0,240],
 "interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[27,0,0,240],
-"interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[26,0,0,241],
 "interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[27,0,0,241],
-"interfacefstarpu__mod_1_1fstarpu__task__init.html":[26,0,0,242],
+"interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[26,0,0,241],
 "interfacefstarpu__mod_1_1fstarpu__task__init.html":[27,0,0,242],
-"interfacefstarpu__mod_1_1fstarpu__task__insert.html":[26,0,0,243],
+"interfacefstarpu__mod_1_1fstarpu__task__init.html":[26,0,0,242],
 "interfacefstarpu__mod_1_1fstarpu__task__insert.html":[27,0,0,243],
-"interfacefstarpu__mod_1_1fstarpu__task__nready.html":[27,0,0,244],
+"interfacefstarpu__mod_1_1fstarpu__task__insert.html":[26,0,0,243],
 "interfacefstarpu__mod_1_1fstarpu__task__nready.html":[26,0,0,244],
-"interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[27,0,0,245],
+"interfacefstarpu__mod_1_1fstarpu__task__nready.html":[27,0,0,244],
 "interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[26,0,0,245],
+"interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[27,0,0,245],
 "interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[26,0,0,246],
 "interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[27,0,0,246],
 "interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html":[26,0,0,247],
 "interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html":[27,0,0,247],
-"interfacefstarpu__mod_1_1fstarpu__task__submit.html":[26,0,0,248],
 "interfacefstarpu__mod_1_1fstarpu__task__submit.html":[27,0,0,248],
-"interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[26,0,0,249],
+"interfacefstarpu__mod_1_1fstarpu__task__submit.html":[26,0,0,248],
 "interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[27,0,0,249],
-"interfacefstarpu__mod_1_1fstarpu__task__wait.html":[27,0,0,250],
+"interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[26,0,0,249],
 "interfacefstarpu__mod_1_1fstarpu__task__wait.html":[26,0,0,250],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[26,0,0,251],
+"interfacefstarpu__mod_1_1fstarpu__task__wait.html":[27,0,0,250],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[27,0,0,251],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[26,0,0,252],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[26,0,0,251],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[27,0,0,252],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[26,0,0,253],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[26,0,0,252],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[27,0,0,253],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[26,0,0,254],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[26,0,0,253],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[27,0,0,254],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[26,0,0,255],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[26,0,0,254],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[27,0,0,255],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[26,0,0,255],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[26,0,0,256],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[27,0,0,256],
-"interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[26,0,0,257],
 "interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[27,0,0,257],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[26,0,0,258],
+"interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[26,0,0,257],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[27,0,0,258],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[26,0,0,258],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[26,0,0,259],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[27,0,0,259],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[27,0,0,260],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[26,0,0,260],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[26,0,0,261],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[27,0,0,261],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[27,0,0,262],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[26,0,0,262],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[27,0,0,263],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[27,0,0,262],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[26,0,0,263],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html":[27,0,0,264],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[27,0,0,263],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html":[26,0,0,264],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html":[27,0,0,264],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ptr.html":[26,0,0,265],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ptr.html":[27,0,0,265],
 "interfacefstarpu__mod_1_1fstarpu__tensor__ptr__register.html":[26,0,0,266],
 "interfacefstarpu__mod_1_1fstarpu__tensor__ptr__register.html":[27,0,0,266],
-"interfacefstarpu__mod_1_1fstarpu__timing__now.html":[27,0,0,267],
 "interfacefstarpu__mod_1_1fstarpu__timing__now.html":[26,0,0,267],
-"interfacefstarpu__mod_1_1fstarpu__topology__print.html":[26,0,0,268],
+"interfacefstarpu__mod_1_1fstarpu__timing__now.html":[27,0,0,267],
 "interfacefstarpu__mod_1_1fstarpu__topology__print.html":[27,0,0,268],
+"interfacefstarpu__mod_1_1fstarpu__topology__print.html":[26,0,0,268],
 "interfacefstarpu__mod_1_1fstarpu__trace__user__event.html":[26,0,0,269],
 "interfacefstarpu__mod_1_1fstarpu__trace__user__event.html":[27,0,0,269],
 "interfacefstarpu__mod_1_1fstarpu__unpack__arg.html":[27,0,0,270],
@@ -232,22 +234,20 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[26,0,0,274],
 "interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[27,0,0,275],
 "interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[26,0,0,275],
-"interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[26,0,0,276],
 "interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[27,0,0,276],
-"interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[26,0,0,277],
+"interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[26,0,0,276],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[27,0,0,277],
+"interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[26,0,0,277],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[26,0,0,278],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[27,0,0,278],
-"interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[26,0,0,279],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[27,0,0,279],
-"interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[27,0,0,280],
+"interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[26,0,0,279],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[26,0,0,280],
-"interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[27,0,0,281],
+"interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[27,0,0,280],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[26,0,0,281],
+"interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[27,0,0,281],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[26,0,0,282],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[27,0,0,282],
-"interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[27,0,0,283],
 "interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[26,0,0,283],
-"interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[27,0,0,284],
-"interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[26,0,0,284]
+"interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[27,0,0,283]
 };
