@@ -1,5 +1,7 @@
 var NAVTREEINDEX13 =
 {
+"interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[27,0,0,284],
+"interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[26,0,0,284],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[27,0,0,285],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[26,0,0,285],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[27,0,0,286],
@@ -8,28 +10,28 @@ var NAVTREEINDEX13 =
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[26,0,0,287],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[27,0,0,288],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[26,0,0,288],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[26,0,0,289],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[27,0,0,289],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[26,0,0,289],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[27,0,0,290],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[26,0,0,290],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[26,0,0,291],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[27,0,0,291],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[26,0,0,291],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[26,0,0,292],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[27,0,0,292],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[26,0,0,293],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[27,0,0,293],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[26,0,0,294],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[26,0,0,293],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[27,0,0,294],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[26,0,0,295],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[26,0,0,294],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[27,0,0,295],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[26,0,0,295],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[27,0,0,296],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[26,0,0,296],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[27,0,0,297],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[26,0,0,297],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[27,0,0,298],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[26,0,0,298],
-"interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[27,0,0,299],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[26,0,0,299],
+"interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[27,0,0,299],
 "interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[27,0,0,300],
 "interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[26,0,0,300],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__barrier.html":[27,0,1,0],
@@ -177,10 +179,10 @@ var NAVTREEINDEX13 =
 "starpu__bound_8h.html":[28,0,1,4],
 "starpu__bound_8h_source.html":[28,0,1,4],
 "starpu__config_8h.html":[28,0,0,0],
-"starpu__config_8h.html#a040eeaf64808762d84ff564d03090266":[28,0,0,0,11],
-"starpu__config_8h.html#a05ed4578d8a766626ad7a774483c9f5c":[28,0,0,0,28],
+"starpu__config_8h.html#a040eeaf64808762d84ff564d03090266":[28,0,0,0,12],
+"starpu__config_8h.html#a05ed4578d8a766626ad7a774483c9f5c":[28,0,0,0,29],
 "starpu__config_8h.html#a08a3c9825f3b8217c1089e97592caf80":[28,0,0,0,5],
-"starpu__config_8h.html#aa535e147c4094f10a17972c417f98d85":[28,0,0,0,27],
+"starpu__config_8h.html#aa535e147c4094f10a17972c417f98d85":[28,0,0,0,28],
 "starpu__config_8h.html#af3e493896eb70d1261709170f1a77c09":[28,0,0,0,4],
 "starpu__config_8h_source.html":[28,0,0,0],
 "starpu__cublas_8h.html":[28,0,1,5],
@@ -247,7 +249,5 @@ var NAVTREEINDEX13 =
 "starpu__perfmodel_8h_source.html":[28,0,1,28],
 "starpu__profiling_8h.html":[28,0,1,29],
 "starpu__profiling_8h_source.html":[28,0,1,29],
-"starpu__profiling__tool_8h.html":[28,0,1,30],
-"starpu__profiling__tool_8h_source.html":[28,0,1,30],
-"starpu__rand_8h.html":[28,0,1,31]
+"starpu__profiling__tool_8h.html":[28,0,1,30]
 };
