@@ -1,5 +1,6 @@
 var NAVTREEINDEX6 =
 {
+"group__API__Miscellaneous__Helpers.html":[25,36],
 "group__API__Miscellaneous__Helpers.html#ga090e97b588f83718c19f0ed3d07d1d70":[25,36,14],
 "group__API__Miscellaneous__Helpers.html#ga0e762c057c5206bd093534e5dd145b1c":[25,36,17],
 "group__API__Miscellaneous__Helpers.html#ga127022a5dde360045b603e47a5faf303":[25,36,20],
@@ -54,79 +55,80 @@ var NAVTREEINDEX6 =
 "group__API__Modularized__Scheduler.html#abf315d3c1f60fbcab6a001f7925dc4fa":[25,22,0,12],
 "group__API__Modularized__Scheduler.html#ac2709f00c42977b8df96d30015fc9cb1":[25,22,0,19],
 "group__API__Modularized__Scheduler.html#ad859296dbded64c8593d613286893a93":[25,22,7,1],
-"group__API__Modularized__Scheduler.html#ga063bc22ea750afba5bebe22e3117258b":[25,22,24],
-"group__API__Modularized__Scheduler.html#ga0b4db1194be324a7cbd2c6486db867d7":[25,22,72],
-"group__API__Modularized__Scheduler.html#ga0c419ef90f6adce7cc9ebca955822dbb":[25,22,62],
-"group__API__Modularized__Scheduler.html#ga0e50b97229fdf62b5006eba35f4d5683":[25,22,23],
+"group__API__Modularized__Scheduler.html#ga063bc22ea750afba5bebe22e3117258b":[25,22,25],
+"group__API__Modularized__Scheduler.html#ga0b4db1194be324a7cbd2c6486db867d7":[25,22,73],
+"group__API__Modularized__Scheduler.html#ga0c419ef90f6adce7cc9ebca955822dbb":[25,22,63],
+"group__API__Modularized__Scheduler.html#ga0e50b97229fdf62b5006eba35f4d5683":[25,22,24],
 "group__API__Modularized__Scheduler.html#ga12e7e5b58b9aebb4f3084fa807c55c40":[25,22,14],
-"group__API__Modularized__Scheduler.html#ga1460e5ad34f360408b3a0003aa0a2b9f":[25,22,45],
-"group__API__Modularized__Scheduler.html#ga17b2f48b9873e1a1b842bb81ed22e972":[25,22,61],
-"group__API__Modularized__Scheduler.html#ga1fd3c2682a57ca9105965b942a5a1313":[25,22,46],
-"group__API__Modularized__Scheduler.html#ga217b0c2bb96b4aa5f0ccda71c2d81f00":[25,22,41],
-"group__API__Modularized__Scheduler.html#ga21df9bf6da463d3b945f0886939b637a":[25,22,48],
-"group__API__Modularized__Scheduler.html#ga231e99e5ce0ecca11b8affebf40bdd9a":[25,22,64],
-"group__API__Modularized__Scheduler.html#ga248d8a1f97615362cb60e78a7ffbf298":[25,22,70],
-"group__API__Modularized__Scheduler.html#ga2a0aac2afe33c1ef0bf3260de25be29e":[25,22,35],
-"group__API__Modularized__Scheduler.html#ga2f27b106110cf20f52ed20e68ecd8613":[25,22,74],
-"group__API__Modularized__Scheduler.html#ga305b8f17f3d49897cebe8376aaede5a2":[25,22,47],
-"group__API__Modularized__Scheduler.html#ga30b0cd3f3d64be88a163a31148c58f1f":[25,22,37],
-"group__API__Modularized__Scheduler.html#ga3ac4da6a19d9f0a34e870e20d6c34966":[25,22,71],
-"group__API__Modularized__Scheduler.html#ga3c60576fc0645bec4cd90c758545fd40":[25,22,75],
+"group__API__Modularized__Scheduler.html#ga1460e5ad34f360408b3a0003aa0a2b9f":[25,22,46],
+"group__API__Modularized__Scheduler.html#ga17b2f48b9873e1a1b842bb81ed22e972":[25,22,62],
+"group__API__Modularized__Scheduler.html#ga1fd3c2682a57ca9105965b942a5a1313":[25,22,47],
+"group__API__Modularized__Scheduler.html#ga217b0c2bb96b4aa5f0ccda71c2d81f00":[25,22,42],
+"group__API__Modularized__Scheduler.html#ga21df9bf6da463d3b945f0886939b637a":[25,22,49],
+"group__API__Modularized__Scheduler.html#ga231e99e5ce0ecca11b8affebf40bdd9a":[25,22,65],
+"group__API__Modularized__Scheduler.html#ga248d8a1f97615362cb60e78a7ffbf298":[25,22,71],
+"group__API__Modularized__Scheduler.html#ga2a0aac2afe33c1ef0bf3260de25be29e":[25,22,36],
+"group__API__Modularized__Scheduler.html#ga2f27b106110cf20f52ed20e68ecd8613":[25,22,75],
+"group__API__Modularized__Scheduler.html#ga305b8f17f3d49897cebe8376aaede5a2":[25,22,48],
+"group__API__Modularized__Scheduler.html#ga30b0cd3f3d64be88a163a31148c58f1f":[25,22,38],
+"group__API__Modularized__Scheduler.html#ga3ac4da6a19d9f0a34e870e20d6c34966":[25,22,72],
+"group__API__Modularized__Scheduler.html#ga3c60576fc0645bec4cd90c758545fd40":[25,22,76],
 "group__API__Modularized__Scheduler.html#ga3f9c54f338cb39029b508f5890b1111a":[25,22,17],
-"group__API__Modularized__Scheduler.html#ga424d5bae6d2c3c99ab4f215b0e23698f":[25,22,57],
-"group__API__Modularized__Scheduler.html#ga478058eac115f3889d6f39273d66a53f":[25,22,29],
-"group__API__Modularized__Scheduler.html#ga48a2bf7d22985f9a810f8a563153e936":[25,22,50],
-"group__API__Modularized__Scheduler.html#ga49a5e198c16a141aee76be2416b7dbb4":[25,22,78],
-"group__API__Modularized__Scheduler.html#ga4a02a60ffa8959fda08292dbf7aa20f7":[25,22,56],
-"group__API__Modularized__Scheduler.html#ga4fd6f598c30dac693e9e5b37f3e450f6":[25,22,66],
-"group__API__Modularized__Scheduler.html#ga502c075e94e2988007333d8f0f80b69c":[25,22,77],
-"group__API__Modularized__Scheduler.html#ga511a8c5bc261cae8153cdfe7670a21a4":[25,22,32],
-"group__API__Modularized__Scheduler.html#ga5c4ea8cd11d331eb39de2c02ce29efb1":[25,22,38],
-"group__API__Modularized__Scheduler.html#ga61c2f443fb8d5b6a2a1404eae0e7868e":[25,22,30],
-"group__API__Modularized__Scheduler.html#ga685a73facd82449b2f21f76f909e4ac3":[25,22,59],
-"group__API__Modularized__Scheduler.html#ga686ebaecfc562cacc98b20bbb7db5ebf":[25,22,33],
-"group__API__Modularized__Scheduler.html#ga699b31664bb3665f25ef360c2512d8f9":[25,22,58],
-"group__API__Modularized__Scheduler.html#ga70c74dee688684fb09e45833094ba21a":[25,22,26],
+"group__API__Modularized__Scheduler.html#ga424d5bae6d2c3c99ab4f215b0e23698f":[25,22,58],
+"group__API__Modularized__Scheduler.html#ga478058eac115f3889d6f39273d66a53f":[25,22,30],
+"group__API__Modularized__Scheduler.html#ga48a2bf7d22985f9a810f8a563153e936":[25,22,51],
+"group__API__Modularized__Scheduler.html#ga49a5e198c16a141aee76be2416b7dbb4":[25,22,79],
+"group__API__Modularized__Scheduler.html#ga4a02a60ffa8959fda08292dbf7aa20f7":[25,22,57],
+"group__API__Modularized__Scheduler.html#ga4fd6f598c30dac693e9e5b37f3e450f6":[25,22,67],
+"group__API__Modularized__Scheduler.html#ga502c075e94e2988007333d8f0f80b69c":[25,22,78],
+"group__API__Modularized__Scheduler.html#ga511a8c5bc261cae8153cdfe7670a21a4":[25,22,33],
+"group__API__Modularized__Scheduler.html#ga5c4ea8cd11d331eb39de2c02ce29efb1":[25,22,39],
+"group__API__Modularized__Scheduler.html#ga61c2f443fb8d5b6a2a1404eae0e7868e":[25,22,31],
+"group__API__Modularized__Scheduler.html#ga685a73facd82449b2f21f76f909e4ac3":[25,22,60],
+"group__API__Modularized__Scheduler.html#ga686ebaecfc562cacc98b20bbb7db5ebf":[25,22,34],
+"group__API__Modularized__Scheduler.html#ga699b31664bb3665f25ef360c2512d8f9":[25,22,59],
+"group__API__Modularized__Scheduler.html#ga6b1f65158357aae0d9239063e54f82a4":[25,22,21],
+"group__API__Modularized__Scheduler.html#ga70c74dee688684fb09e45833094ba21a":[25,22,27],
 "group__API__Modularized__Scheduler.html#ga72554d14205573f57631b850afa3f39f":[25,22,11],
-"group__API__Modularized__Scheduler.html#ga752889050651f6e3c83ddd2c3f96c0ff":[25,22,63],
-"group__API__Modularized__Scheduler.html#ga782b27a1b864b0d21294f3d8da8756f8":[25,22,60],
-"group__API__Modularized__Scheduler.html#ga79594b4403678fa1d6aa08f7fbe6e525":[25,22,44],
-"group__API__Modularized__Scheduler.html#ga795d692f797ef022c350c9b5922cec31":[25,22,40],
+"group__API__Modularized__Scheduler.html#ga752889050651f6e3c83ddd2c3f96c0ff":[25,22,64],
+"group__API__Modularized__Scheduler.html#ga782b27a1b864b0d21294f3d8da8756f8":[25,22,61],
+"group__API__Modularized__Scheduler.html#ga79594b4403678fa1d6aa08f7fbe6e525":[25,22,45],
+"group__API__Modularized__Scheduler.html#ga795d692f797ef022c350c9b5922cec31":[25,22,41],
 "group__API__Modularized__Scheduler.html#ga7bacda898bdd7964b21ce611c7db077b":[25,22,10],
-"group__API__Modularized__Scheduler.html#ga7ceaaeea8cc10f6d67706c4ee33e93ce":[25,22,36],
-"group__API__Modularized__Scheduler.html#ga813c6be6ae07ec5fe6e54a1bd97267ce":[25,22,21],
-"group__API__Modularized__Scheduler.html#ga862bc72530533cc7eab28294676f5318":[25,22,55],
-"group__API__Modularized__Scheduler.html#ga87785b9c9eeb3718d85dc1b2a24fab26":[25,22,28],
-"group__API__Modularized__Scheduler.html#ga8efad6df3a5b036619ea5c76fe50a0c5":[25,22,51],
-"group__API__Modularized__Scheduler.html#ga90dfe435a72d46bd23ddaffa287833c2":[25,22,39],
+"group__API__Modularized__Scheduler.html#ga7ceaaeea8cc10f6d67706c4ee33e93ce":[25,22,37],
+"group__API__Modularized__Scheduler.html#ga813c6be6ae07ec5fe6e54a1bd97267ce":[25,22,22],
+"group__API__Modularized__Scheduler.html#ga862bc72530533cc7eab28294676f5318":[25,22,56],
+"group__API__Modularized__Scheduler.html#ga87785b9c9eeb3718d85dc1b2a24fab26":[25,22,29],
+"group__API__Modularized__Scheduler.html#ga8efad6df3a5b036619ea5c76fe50a0c5":[25,22,52],
+"group__API__Modularized__Scheduler.html#ga90dfe435a72d46bd23ddaffa287833c2":[25,22,40],
 "group__API__Modularized__Scheduler.html#ga966aaa040948551bede3ee46c9f8847e":[25,22,18],
-"group__API__Modularized__Scheduler.html#ga9bfbf9eb07c5ccc7c77a40ddb37056b8":[25,22,67],
-"group__API__Modularized__Scheduler.html#ga9ed484d5707136420880285afe55bd3d":[25,22,43],
-"group__API__Modularized__Scheduler.html#gaa207453a69f029b2f3c74bc8b9cffde2":[25,22,69],
+"group__API__Modularized__Scheduler.html#ga9bfbf9eb07c5ccc7c77a40ddb37056b8":[25,22,68],
+"group__API__Modularized__Scheduler.html#ga9ed484d5707136420880285afe55bd3d":[25,22,44],
+"group__API__Modularized__Scheduler.html#gaa207453a69f029b2f3c74bc8b9cffde2":[25,22,70],
 "group__API__Modularized__Scheduler.html#gaa838921844068ca3190dca5e2b5a99db":[25,22,13],
-"group__API__Modularized__Scheduler.html#gaab8471a2921b0508b9269b08ecfba3b7":[25,22,42],
-"group__API__Modularized__Scheduler.html#gab17420484cfb68122d986d1feee91905":[25,22,76],
-"group__API__Modularized__Scheduler.html#gab40975877d0c861348ccc96602be2cae":[25,22,25],
-"group__API__Modularized__Scheduler.html#gab8540c0e69c3af17c424944af9b3c802":[25,22,27],
+"group__API__Modularized__Scheduler.html#gaab8471a2921b0508b9269b08ecfba3b7":[25,22,43],
+"group__API__Modularized__Scheduler.html#gab17420484cfb68122d986d1feee91905":[25,22,77],
+"group__API__Modularized__Scheduler.html#gab40975877d0c861348ccc96602be2cae":[25,22,26],
+"group__API__Modularized__Scheduler.html#gab8540c0e69c3af17c424944af9b3c802":[25,22,28],
 "group__API__Modularized__Scheduler.html#gabd7a0274979659050496fcc1c66b7a1c":[25,22,8],
-"group__API__Modularized__Scheduler.html#gabf51817bd8f2a32af327d90eb5d126ec":[25,22,54],
-"group__API__Modularized__Scheduler.html#gac3ab95326f770ecd208a9949d18ceddf":[25,22,65],
-"group__API__Modularized__Scheduler.html#gac863df9e289543dcfd6a0b5e4e60432a":[25,22,22],
-"group__API__Modularized__Scheduler.html#gaccfaa23c5e0948fec6be5f71fc69f32c":[25,22,73],
-"group__API__Modularized__Scheduler.html#gad06fa143512ae761c452bf0adf685bae":[25,22,53],
+"group__API__Modularized__Scheduler.html#gabf51817bd8f2a32af327d90eb5d126ec":[25,22,55],
+"group__API__Modularized__Scheduler.html#gac3ab95326f770ecd208a9949d18ceddf":[25,22,66],
+"group__API__Modularized__Scheduler.html#gac863df9e289543dcfd6a0b5e4e60432a":[25,22,23],
+"group__API__Modularized__Scheduler.html#gaccfaa23c5e0948fec6be5f71fc69f32c":[25,22,74],
+"group__API__Modularized__Scheduler.html#gad06fa143512ae761c452bf0adf685bae":[25,22,54],
 "group__API__Modularized__Scheduler.html#gad0e17cdc3def6bd7e9a9a17437969bdb":[25,22,19],
-"group__API__Modularized__Scheduler.html#gad76ac70069357b5a3d0ac0a1489016a2":[25,22,68],
+"group__API__Modularized__Scheduler.html#gad76ac70069357b5a3d0ac0a1489016a2":[25,22,69],
 "group__API__Modularized__Scheduler.html#gae1aa931285a2b952473fc7def121c5cd":[25,22,16],
-"group__API__Modularized__Scheduler.html#gae1ac4bb35944de31705ba297aef1f9a1":[25,22,49],
+"group__API__Modularized__Scheduler.html#gae1ac4bb35944de31705ba297aef1f9a1":[25,22,50],
 "group__API__Modularized__Scheduler.html#gae4532cd31d9d069b810bdf52db2e052e":[25,22,15],
 "group__API__Modularized__Scheduler.html#gae4fc13eee5dd3528951a5cfea33c03ce":[25,22,12],
-"group__API__Modularized__Scheduler.html#gae97d6b25d8143ef2f7b6260c6f550c5c":[25,22,31],
-"group__API__Modularized__Scheduler.html#gaec7ff28a32f69a93850a1233a1c2725f":[25,22,34],
+"group__API__Modularized__Scheduler.html#gae97d6b25d8143ef2f7b6260c6f550c5c":[25,22,32],
+"group__API__Modularized__Scheduler.html#gaec7ff28a32f69a93850a1233a1c2725f":[25,22,35],
 "group__API__Modularized__Scheduler.html#gafb485fe5fb1f46c7ce7eb505815f306b":[25,22,9],
 "group__API__Modularized__Scheduler.html#gafb5ce04aff2175aed3763a72bf252107":[25,22,20],
-"group__API__Modularized__Scheduler.html#gafb683e254b5084a1321a21fde5139b01":[25,22,52],
-"group__API__Modularized__Scheduler.html#ggab40975877d0c861348ccc96602be2caea27934b03d9ff6827b318124ff683fb40":[25,22,25,0],
-"group__API__Modularized__Scheduler.html#ggab40975877d0c861348ccc96602be2caea40dba09874d6d3a220669e0ccea27da2":[25,22,25,1],
+"group__API__Modularized__Scheduler.html#gafb683e254b5084a1321a21fde5139b01":[25,22,53],
+"group__API__Modularized__Scheduler.html#ggab40975877d0c861348ccc96602be2caea27934b03d9ff6827b318124ff683fb40":[25,22,26,0],
+"group__API__Modularized__Scheduler.html#ggab40975877d0c861348ccc96602be2caea40dba09874d6d3a220669e0ccea27da2":[25,22,26,1],
 "group__API__Modularized__Scheduler.html#structstarpu__sched__component":[25,22,0],
 "group__API__Modularized__Scheduler.html#structstarpu__sched__component__fifo__data":[25,22,2],
 "group__API__Modularized__Scheduler.html#structstarpu__sched__component__heteroprio__data":[25,22,5],
@@ -247,7 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__OpenMP__Runtime__Support.html#gaa15212ca3137d7aba827794b26fee9e0":[25,21,44],
 "group__API__OpenMP__Runtime__Support.html#gaa3127cc9d95397b4f066cef20f9ef99d":[25,21,17],
 "group__API__OpenMP__Runtime__Support.html#gaa4b70af0a6cf757e05e300c5eeea0a46":[25,21,8],
-"group__API__OpenMP__Runtime__Support.html#gaa5c38dfec313088ca5e527a97f40969d":[25,21,7],
-"group__API__OpenMP__Runtime__Support.html#gaa63576df9729394a3d53137d7021bab5":[25,21,35],
-"group__API__OpenMP__Runtime__Support.html#gaa862fb6fec908c7707daa274ae5950bd":[25,21,90]
+"group__API__OpenMP__Runtime__Support.html#gaa5c38dfec313088ca5e527a97f40969d":[25,21,7]
 };
