@@ -1,5 +1,7 @@
 var NAVTREEINDEX8 =
 {
+"group__API__Performance__Model.html#aa22dc6b2674ed810366dc300f4abd7cc":[25,20,6,9],
+"group__API__Performance__Model.html#aa69cc173b9ebdbf129eb1b30ca64ddd9":[25,20,4,7],
 "group__API__Performance__Model.html#aa82fae955253d333733d34fe4a44e298":[25,20,5,1],
 "group__API__Performance__Model.html#ab1a7822099d984503f1c67d45ab6f4b8":[25,20,2,2],
 "group__API__Performance__Model.html#ab718a53c300f99766bdc42ca1909b49b":[25,20,4,9],
@@ -247,7 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__SC__Hypervisor__usage.html#ga15d008933c3c89906f613b3a24fff3cc":[25,49,0],
 "group__API__SC__Hypervisor__usage.html#ga37713b9ab6d282f2b705240e630f1a4c":[25,49,10],
 "group__API__SC__Hypervisor__usage.html#ga4c83e2984867267ea8c7da9fbaf23858":[25,49,2],
-"group__API__SC__Hypervisor__usage.html#ga4dfbeda855bb8963c5332fdd796c0dcf":[25,49,18],
-"group__API__SC__Hypervisor__usage.html#ga5f2b33a41a697759ee2a222e623f723c":[25,49,4],
-"group__API__SC__Hypervisor__usage.html#ga5f34faa17f98f25bd874950ba1a15578":[25,49,15]
+"group__API__SC__Hypervisor__usage.html#ga4dfbeda855bb8963c5332fdd796c0dcf":[25,49,18]
 };
