@@ -1,5 +1,7 @@
 var NAVTREEINDEX9 =
 {
+"group__API__SC__Hypervisor__usage.html#ga5f2b33a41a697759ee2a222e623f723c":[25,49,4],
+"group__API__SC__Hypervisor__usage.html#ga5f34faa17f98f25bd874950ba1a15578":[25,49,15],
 "group__API__SC__Hypervisor__usage.html#ga6398be50d801f0fc5ad73506e392d476":[25,49,17],
 "group__API__SC__Hypervisor__usage.html#ga67d1dbb2ab01c8b712a9cd270fba4155":[25,49,5],
 "group__API__SC__Hypervisor__usage.html#ga6fd674769c96a6b13b4e1b0d2e5a4f68":[25,49,20],
@@ -247,7 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__Threads.html#ga4f00fbbe6f909998ecec7c3cc3715e21":[25,3,55],
 "group__API__Threads.html#ga5bc60d93e1403658c30c998d1b6edd11":[25,3,52],
 "group__API__Threads.html#ga5e53025adc42966a97d616304bd654bd":[25,3,6],
-"group__API__Threads.html#ga5ec606cedc543ee35f3c7dc8a8e2505b":[25,3,64],
-"group__API__Threads.html#ga629152a86070cd58811fa17506f7995e":[25,3,12],
-"group__API__Threads.html#ga654b486b4161002221a75cc619eabe48":[25,3,30]
+"group__API__Threads.html#ga5ec606cedc543ee35f3c7dc8a8e2505b":[25,3,64]
 };
