@@ -1,5 +1,7 @@
 var NAVTREEINDEX6 =
 {
+"group__API__OpenCL__Extensions.html#a685357d9709ece920bf269a917ed8297":[5,15,0,0],
+"group__API__OpenCL__Extensions.html#ga002e85a0f6bcd087df54287de5ae5e07":[5,15,30],
 "group__API__OpenCL__Extensions.html#ga03f34ac98495afc5d0f268e366f80598":[5,15,15],
 "group__API__OpenCL__Extensions.html#ga06f19c27ac5147607acc511d49302321":[5,15,26],
 "group__API__OpenCL__Extensions.html#ga160dc78c0f6a90b5aa2200b49c5b4d7b":[5,15,1],
@@ -247,7 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__Perf__Monitoring.html#ga0d09d776a8250c995d3e40d77bb10628":[5,38,33],
 "group__API__Perf__Monitoring.html#ga13f8e7f707f5bab7bc4f45291effd109":[5,38,15],
 "group__API__Perf__Monitoring.html#ga15b96ecd4161e8abdea440ad89262766":[5,38,24],
-"group__API__Perf__Monitoring.html#ga1d3b734cccfcb02c47baa5412acf0877":[5,38,1],
-"group__API__Perf__Monitoring.html#ga247ff710854bfd7e3ab976b2ebad478e":[5,38,11],
-"group__API__Perf__Monitoring.html#ga2f9ddf6ae47cd7eba9b94499e37a301f":[5,38,13]
+"group__API__Perf__Monitoring.html#ga1d3b734cccfcb02c47baa5412acf0877":[5,38,1]
 };
