@@ -1,5 +1,7 @@
 var NAVTREEINDEX7 =
 {
+"group__API__Perf__Monitoring.html#ga247ff710854bfd7e3ab976b2ebad478e":[5,38,11],
+"group__API__Perf__Monitoring.html#ga2f9ddf6ae47cd7eba9b94499e37a301f":[5,38,13],
 "group__API__Perf__Monitoring.html#ga36c44ab10f14200d43704d8771246997":[5,38,8],
 "group__API__Perf__Monitoring.html#ga42a36dd17bcfd33dcca53e8cc28f56a7":[5,38,3],
 "group__API__Perf__Monitoring.html#ga466359135ffda3634e03a9c90809a71b":[5,38,26],
@@ -247,7 +249,5 @@ var NAVTREEINDEX7 =
 "group__API__Profiling__Tool.html#unionstarpu__prof__tool__event__info":[5,41,1],
 "group__API__Random__Functions.html":[5,42],
 "group__API__Running__Drivers.html":[5,32],
-"group__API__Running__Drivers.html#a08415dd427f53b10ce4176ad77fade39":[5,32,0,1],
-"group__API__Running__Drivers.html#a50af396b52e8c54e4e3b23803105fc0e":[5,32,0,0],
-"group__API__Running__Drivers.html#ga119a52234aebe7fef5da42f9d3989402":[5,32,2]
+"group__API__Running__Drivers.html#a08415dd427f53b10ce4176ad77fade39":[5,32,0,1]
 };
