@@ -1,5 +1,7 @@
 var NAVTREEINDEX9 =
 {
+"group__API__Scheduling__Policy.html#ga98ec28ae7ac484959f48b7a79372c1af":[5,24,31],
+"group__API__Scheduling__Policy.html#ga9e576ab0869a671c3cc482f385e1905b":[5,24,7],
 "group__API__Scheduling__Policy.html#gaa01a5b65a4c387da5f7ca711c03d41c8":[5,24,9],
 "group__API__Scheduling__Policy.html#gaa859b0ee59cfa2bde4d241f854c3bbea":[5,24,29],
 "group__API__Scheduling__Policy.html#gab291c2011e9679a07d2eb632d58ac90c":[5,24,38],
@@ -247,7 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__Workers.html#gaad05388dbafdd5397ebe080913a7b0c8":[5,18,19],
 "group__API__Workers.html#gaafe3ee2f7b074f95e8bc79eeabda0f0f":[5,18,4],
 "group__API__Workers.html#gab0ffe5622c5980444226f1ed8d6fee71":[5,18,27],
-"group__API__Workers.html#gab48ee9207771b65673f5bb18885c8a7c":[5,18,12],
-"group__API__Workers.html#gab568e2368c11f9fb362f04264ad4cd04":[5,18,65],
-"group__API__Workers.html#gabb530cc7597d5a135b900760f45c9cde":[5,18,61]
+"group__API__Workers.html#gab48ee9207771b65673f5bb18885c8a7c":[5,18,12]
 };
