@@ -1,35 +1,37 @@
 var NAVTREEINDEX12 =
 {
+"interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[8,0,0,227],
+"interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[9,0,0,227],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait.html":[8,0,0,228],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait.html":[9,0,0,228],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html":[8,0,0,229],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html":[9,0,0,229],
-"interfacefstarpu__mod_1_1fstarpu__task__clean.html":[9,0,0,230],
 "interfacefstarpu__mod_1_1fstarpu__task__clean.html":[8,0,0,230],
+"interfacefstarpu__mod_1_1fstarpu__task__clean.html":[9,0,0,230],
 "interfacefstarpu__mod_1_1fstarpu__task__create.html":[9,0,0,231],
 "interfacefstarpu__mod_1_1fstarpu__task__create.html":[8,0,0,231],
 "interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[9,0,0,232],
 "interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[8,0,0,232],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[9,0,0,233],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[8,0,0,233],
-"interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[8,0,0,234],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[9,0,0,234],
-"interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[8,0,0,235],
+"interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[8,0,0,234],
 "interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[9,0,0,235],
+"interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[8,0,0,235],
 "interfacefstarpu__mod_1_1fstarpu__task__dup.html":[9,0,0,236],
 "interfacefstarpu__mod_1_1fstarpu__task__dup.html":[8,0,0,236],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[9,0,0,237],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[8,0,0,237],
-"interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[9,0,0,238],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[8,0,0,238],
-"interfacefstarpu__mod_1_1fstarpu__task__finished.html":[9,0,0,239],
+"interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[9,0,0,238],
 "interfacefstarpu__mod_1_1fstarpu__task__finished.html":[8,0,0,239],
+"interfacefstarpu__mod_1_1fstarpu__task__finished.html":[9,0,0,239],
 "interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[8,0,0,240],
 "interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[9,0,0,240],
-"interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[8,0,0,241],
 "interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[9,0,0,241],
-"interfacefstarpu__mod_1_1fstarpu__task__init.html":[8,0,0,242],
+"interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[8,0,0,241],
 "interfacefstarpu__mod_1_1fstarpu__task__init.html":[9,0,0,242],
+"interfacefstarpu__mod_1_1fstarpu__task__init.html":[8,0,0,242],
 "interfacefstarpu__mod_1_1fstarpu__task__insert.html":[9,0,0,243],
 "interfacefstarpu__mod_1_1fstarpu__task__insert.html":[8,0,0,243],
 "interfacefstarpu__mod_1_1fstarpu__task__nready.html":[9,0,0,244],
@@ -38,56 +40,56 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[8,0,0,245],
 "interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[9,0,0,246],
 "interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[8,0,0,246],
-"interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html":[9,0,0,247],
 "interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html":[8,0,0,247],
-"interfacefstarpu__mod_1_1fstarpu__task__submit.html":[9,0,0,248],
+"interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html":[9,0,0,247],
 "interfacefstarpu__mod_1_1fstarpu__task__submit.html":[8,0,0,248],
-"interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[9,0,0,249],
+"interfacefstarpu__mod_1_1fstarpu__task__submit.html":[9,0,0,248],
 "interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[8,0,0,249],
-"interfacefstarpu__mod_1_1fstarpu__task__wait.html":[9,0,0,250],
+"interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[9,0,0,249],
 "interfacefstarpu__mod_1_1fstarpu__task__wait.html":[8,0,0,250],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[9,0,0,251],
+"interfacefstarpu__mod_1_1fstarpu__task__wait.html":[9,0,0,250],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[8,0,0,251],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[9,0,0,251],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[8,0,0,252],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[9,0,0,252],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[9,0,0,253],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[8,0,0,253],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[9,0,0,254],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[8,0,0,254],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[8,0,0,255],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[9,0,0,255],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[8,0,0,256],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[8,0,0,255],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[9,0,0,256],
-"interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[8,0,0,257],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[8,0,0,256],
 "interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[9,0,0,257],
+"interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[8,0,0,257],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[9,0,0,258],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[8,0,0,258],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[9,0,0,259],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[8,0,0,259],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[8,0,0,260],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[9,0,0,260],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[8,0,0,260],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[9,0,0,261],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[8,0,0,261],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[9,0,0,262],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[8,0,0,262],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[9,0,0,262],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[8,0,0,263],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[9,0,0,263],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html":[9,0,0,264],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html":[8,0,0,264],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ptr.html":[8,0,0,265],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html":[9,0,0,264],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ptr.html":[9,0,0,265],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ptr.html":[8,0,0,265],
 "interfacefstarpu__mod_1_1fstarpu__tensor__ptr__register.html":[8,0,0,266],
 "interfacefstarpu__mod_1_1fstarpu__tensor__ptr__register.html":[9,0,0,266],
-"interfacefstarpu__mod_1_1fstarpu__timing__now.html":[8,0,0,267],
 "interfacefstarpu__mod_1_1fstarpu__timing__now.html":[9,0,0,267],
-"interfacefstarpu__mod_1_1fstarpu__topology__print.html":[8,0,0,268],
+"interfacefstarpu__mod_1_1fstarpu__timing__now.html":[8,0,0,267],
 "interfacefstarpu__mod_1_1fstarpu__topology__print.html":[9,0,0,268],
+"interfacefstarpu__mod_1_1fstarpu__topology__print.html":[8,0,0,268],
 "interfacefstarpu__mod_1_1fstarpu__trace__user__event.html":[8,0,0,269],
 "interfacefstarpu__mod_1_1fstarpu__trace__user__event.html":[9,0,0,269],
 "interfacefstarpu__mod_1_1fstarpu__unpack__arg.html":[8,0,0,270],
 "interfacefstarpu__mod_1_1fstarpu__unpack__arg.html":[9,0,0,270],
-"interfacefstarpu__mod_1_1fstarpu__usleep.html":[9,0,0,271],
 "interfacefstarpu__mod_1_1fstarpu__usleep.html":[8,0,0,271],
+"interfacefstarpu__mod_1_1fstarpu__usleep.html":[9,0,0,271],
 "interfacefstarpu__mod_1_1fstarpu__variable__data__register.html":[8,0,0,272],
 "interfacefstarpu__mod_1_1fstarpu__variable__data__register.html":[9,0,0,272],
 "interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html":[8,0,0,273],
@@ -96,22 +98,22 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[9,0,0,274],
 "interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[8,0,0,275],
 "interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[9,0,0,275],
-"interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[8,0,0,276],
 "interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[9,0,0,276],
+"interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[8,0,0,276],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[9,0,0,277],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[8,0,0,277],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[8,0,0,278],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[9,0,0,278],
-"interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[8,0,0,279],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[9,0,0,279],
+"interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[8,0,0,279],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[9,0,0,280],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[8,0,0,280],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[9,0,0,281],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[8,0,0,281],
-"interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[8,0,0,282],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[9,0,0,282],
-"interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[8,0,0,283],
+"interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[8,0,0,282],
 "interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[9,0,0,283],
+"interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[8,0,0,283],
 "interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[8,0,0,284],
 "interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[9,0,0,284],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[8,0,0,285],
@@ -120,14 +122,14 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[9,0,0,286],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[9,0,0,287],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[8,0,0,287],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[9,0,0,288],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[8,0,0,288],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[9,0,0,288],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[8,0,0,289],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[9,0,0,289],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[9,0,0,290],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[8,0,0,290],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[9,0,0,291],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[9,0,0,290],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[8,0,0,291],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[9,0,0,291],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[9,0,0,292],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[8,0,0,292],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[8,0,0,293],
@@ -140,12 +142,12 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[8,0,0,296],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[9,0,0,297],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[8,0,0,297],
-"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[9,0,0,298],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[8,0,0,298],
+"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[9,0,0,298],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[9,0,0,299],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[8,0,0,299],
-"interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[8,0,0,300],
 "interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[9,0,0,300],
+"interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[8,0,0,300],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__barrier.html":[9,0,1,0],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__flush.html":[9,0,1,1],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__flush__all__data.html":[9,0,1,2],
@@ -247,7 +249,5 @@ var NAVTREEINDEX12 =
 "sc__hypervisor__config_8h.html#afdb68c657fb202f52938f5268749003d":[10,0,3,0,1,0,5],
 "sc__hypervisor__config_8h.html#structsc__hypervisor__policy__config":[10,0,3,0,1,0],
 "sc__hypervisor__config_8h_source.html":[10,0,3,0,1],
-"sc__hypervisor__lp_8h.html":[10,0,3,0,2],
-"sc__hypervisor__lp_8h_source.html":[10,0,3,0,2],
-"sc__hypervisor__monitoring_8h.html":[10,0,3,0,3]
+"sc__hypervisor__lp_8h.html":[10,0,3,0,2]
 };
