@@ -1,5 +1,7 @@
 var NAVTREEINDEX13 =
 {
+"sc__hypervisor__lp_8h_source.html":[10,0,3,0,2],
+"sc__hypervisor__monitoring_8h.html":[10,0,3,0,3],
 "sc__hypervisor__monitoring_8h.html#a063487ad1a8059812b5c4f721bf828f6":[10,0,3,0,3,0,22],
 "sc__hypervisor__monitoring_8h.html#a0786fc47b4d17d660cfe66649e4933e7":[10,0,3,0,3,0,9],
 "sc__hypervisor__monitoring_8h.html#a0cd92328373b9b5427e6bb48a44d8644":[10,0,3,0,3,0,2],
@@ -41,10 +43,10 @@ var NAVTREEINDEX13 =
 "starpu__bound_8h.html":[10,0,1,4],
 "starpu__bound_8h_source.html":[10,0,1,4],
 "starpu__config_8h.html":[10,0,0,0],
-"starpu__config_8h.html#a040eeaf64808762d84ff564d03090266":[10,0,0,0,11],
-"starpu__config_8h.html#a05ed4578d8a766626ad7a774483c9f5c":[10,0,0,0,28],
+"starpu__config_8h.html#a040eeaf64808762d84ff564d03090266":[10,0,0,0,12],
+"starpu__config_8h.html#a05ed4578d8a766626ad7a774483c9f5c":[10,0,0,0,29],
 "starpu__config_8h.html#a08a3c9825f3b8217c1089e97592caf80":[10,0,0,0,5],
-"starpu__config_8h.html#aa535e147c4094f10a17972c417f98d85":[10,0,0,0,27],
+"starpu__config_8h.html#aa535e147c4094f10a17972c417f98d85":[10,0,0,0,28],
 "starpu__config_8h.html#af3e493896eb70d1261709170f1a77c09":[10,0,0,0,4],
 "starpu__config_8h_source.html":[10,0,0,0],
 "starpu__cublas_8h.html":[10,0,1,5],
