@@ -1,5 +1,6 @@
 var NAVTREEINDEX2 =
 {
+"group__API__Data__Interfaces.html#ae039cff4622424d30f99811665f4de4f":[7,9,10,6],
 "group__API__Data__Interfaces.html#ae04050a90bd86fe5b8462b62aaa9547e":[7,9,0,16],
 "group__API__Data__Interfaces.html#ae1d888af673475dbcf85104b6c359a6e":[7,9,0,12],
 "group__API__Data__Interfaces.html#ae2a9b938ace8afeb6de759dadb7181a5":[7,9,4,0],
@@ -248,6 +249,5 @@ var NAVTREEINDEX2 =
 "group__API__Data__Interfaces.html#structstarpu__data__interface__ops":[7,9,1],
 "group__API__Data__Interfaces.html#structstarpu__matrix__interface":[7,9,2],
 "group__API__Data__Interfaces.html#structstarpu__multiformat__data__interface__ops":[7,9,11],
-"group__API__Data__Interfaces.html#structstarpu__multiformat__interface":[7,9,12],
-"group__API__Data__Interfaces.html#structstarpu__ndim__interface":[7,9,6]
+"group__API__Data__Interfaces.html#structstarpu__multiformat__interface":[7,9,12]
 };
