@@ -1,5 +1,7 @@
 var NAVTREEINDEX6 =
 {
+"group__API__Modularized__Scheduler.html#structstarpu__sched__tree":[7,22,1],
+"group__API__OpenCL__Extensions.html":[7,15],
 "group__API__OpenCL__Extensions.html#a685357d9709ece920bf269a917ed8297":[7,15,0,0],
 "group__API__OpenCL__Extensions.html#ga002e85a0f6bcd087df54287de5ae5e07":[7,15,30],
 "group__API__OpenCL__Extensions.html#ga03f34ac98495afc5d0f268e366f80598":[7,15,15],
@@ -247,7 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__Perf__Monitoring.html#ga000af6e254ec5a3e95868f50d354f693":[7,38,4],
 "group__API__Perf__Monitoring.html#ga0a9c21a6b765059a5f5f72ab10dd99fa":[7,38,12],
 "group__API__Perf__Monitoring.html#ga0d09d776a8250c995d3e40d77bb10628":[7,38,33],
-"group__API__Perf__Monitoring.html#ga13f8e7f707f5bab7bc4f45291effd109":[7,38,15],
-"group__API__Perf__Monitoring.html#ga15b96ecd4161e8abdea440ad89262766":[7,38,24],
-"group__API__Perf__Monitoring.html#ga1d3b734cccfcb02c47baa5412acf0877":[7,38,1]
+"group__API__Perf__Monitoring.html#ga13f8e7f707f5bab7bc4f45291effd109":[7,38,15]
 };
