@@ -1,5 +1,7 @@
 var NAVTREEINDEX7 =
 {
+"group__API__Perf__Monitoring.html#ga15b96ecd4161e8abdea440ad89262766":[7,38,24],
+"group__API__Perf__Monitoring.html#ga1d3b734cccfcb02c47baa5412acf0877":[7,38,1],
 "group__API__Perf__Monitoring.html#ga247ff710854bfd7e3ab976b2ebad478e":[7,38,11],
 "group__API__Perf__Monitoring.html#ga2f9ddf6ae47cd7eba9b94499e37a301f":[7,38,13],
 "group__API__Perf__Monitoring.html#ga36c44ab10f14200d43704d8771246997":[7,38,8],
@@ -247,7 +249,5 @@ var NAVTREEINDEX7 =
 "group__API__Profiling__Tool.html#structstarpu__prof__tool__api__info":[7,41,2],
 "group__API__Profiling__Tool.html#structstarpu__prof__tool__info":[7,41,0],
 "group__API__Profiling__Tool.html#unionstarpu__prof__tool__event__info":[7,41,1],
-"group__API__Random__Functions.html":[7,42],
-"group__API__Running__Drivers.html":[7,32],
-"group__API__Running__Drivers.html#a08415dd427f53b10ce4176ad77fade39":[7,32,0,1]
+"group__API__Random__Functions.html":[7,42]
 };
