@@ -1,5 +1,7 @@
 var NAVTREEINDEX9 =
 {
+"group__API__Scheduling__Policy.html#ga9424eb90a56d08f804d85be6557ddf66":[7,24,45],
+"group__API__Scheduling__Policy.html#ga94edfd4a02666d8c1b8c506423586426":[7,24,19],
 "group__API__Scheduling__Policy.html#ga98ec28ae7ac484959f48b7a79372c1af":[7,24,31],
 "group__API__Scheduling__Policy.html#ga9e576ab0869a671c3cc482f385e1905b":[7,24,7],
 "group__API__Scheduling__Policy.html#gaa01a5b65a4c387da5f7ca711c03d41c8":[7,24,9],
@@ -247,7 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__Workers.html#gaa6e5fd90ba1b431ed025006d190fb421":[7,18,5],
 "group__API__Workers.html#gaa7a73dac05f65d5760abf29016e251f0":[7,18,3],
 "group__API__Workers.html#gaad05388dbafdd5397ebe080913a7b0c8":[7,18,19],
-"group__API__Workers.html#gaafe3ee2f7b074f95e8bc79eeabda0f0f":[7,18,4],
-"group__API__Workers.html#gab0ffe5622c5980444226f1ed8d6fee71":[7,18,27],
-"group__API__Workers.html#gab48ee9207771b65673f5bb18885c8a7c":[7,18,12]
+"group__API__Workers.html#gaafe3ee2f7b074f95e8bc79eeabda0f0f":[7,18,4]
 };
