@@ -1,15 +1,16 @@
 var NAVTREEINDEX11 =
 {
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block.html":[7,0,0,115],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block__shadow.html":[6,0,0,116],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block__shadow.html":[7,0,0,116],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block.html":[6,0,0,117],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block.html":[7,0,0,117],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block__shadow.html":[7,0,0,118],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block__shadow.html":[6,0,0,118],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__csr__filter__vertical__block.html":[6,0,0,119],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block__shadow.html":[7,0,0,118],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__csr__filter__vertical__block.html":[7,0,0,119],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block.html":[7,0,0,120],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__csr__filter__vertical__block.html":[6,0,0,119],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block.html":[6,0,0,120],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block.html":[7,0,0,120],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block__shadow.html":[7,0,0,121],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block__shadow.html":[6,0,0,121],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block.html":[7,0,0,122],
@@ -26,40 +27,40 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__list.html":[6,0,0,127],
 "interfacefstarpu__mod_1_1fstarpu__display__memory__stats.html":[7,0,0,128],
 "interfacefstarpu__mod_1_1fstarpu__display__memory__stats.html":[6,0,0,128],
-"interfacefstarpu__mod_1_1fstarpu__display__stats.html":[6,0,0,129],
 "interfacefstarpu__mod_1_1fstarpu__display__stats.html":[7,0,0,129],
+"interfacefstarpu__mod_1_1fstarpu__display__stats.html":[6,0,0,129],
 "interfacefstarpu__mod_1_1fstarpu__do__schedule.html":[7,0,0,130],
 "interfacefstarpu__mod_1_1fstarpu__do__schedule.html":[6,0,0,130],
-"interfacefstarpu__mod_1_1fstarpu__free__noflag.html":[7,0,0,131],
 "interfacefstarpu__mod_1_1fstarpu__free__noflag.html":[6,0,0,131],
+"interfacefstarpu__mod_1_1fstarpu__free__noflag.html":[7,0,0,131],
 "interfacefstarpu__mod_1_1fstarpu__free__on__node.html":[7,0,0,132],
 "interfacefstarpu__mod_1_1fstarpu__free__on__node.html":[6,0,0,132],
 "interfacefstarpu__mod_1_1fstarpu__fxt__autostart__profiling.html":[7,0,0,133],
 "interfacefstarpu__mod_1_1fstarpu__fxt__autostart__profiling.html":[6,0,0,133],
 "interfacefstarpu__mod_1_1fstarpu__fxt__generate__trace.html":[7,0,0,134],
 "interfacefstarpu__mod_1_1fstarpu__fxt__generate__trace.html":[6,0,0,134],
-"interfacefstarpu__mod_1_1fstarpu__fxt__options__init.html":[6,0,0,135],
 "interfacefstarpu__mod_1_1fstarpu__fxt__options__init.html":[7,0,0,135],
-"interfacefstarpu__mod_1_1fstarpu__fxt__start__profiling.html":[7,0,0,136],
+"interfacefstarpu__mod_1_1fstarpu__fxt__options__init.html":[6,0,0,135],
 "interfacefstarpu__mod_1_1fstarpu__fxt__start__profiling.html":[6,0,0,136],
-"interfacefstarpu__mod_1_1fstarpu__fxt__stop__profiling.html":[7,0,0,137],
+"interfacefstarpu__mod_1_1fstarpu__fxt__start__profiling.html":[7,0,0,136],
 "interfacefstarpu__mod_1_1fstarpu__fxt__stop__profiling.html":[6,0,0,137],
+"interfacefstarpu__mod_1_1fstarpu__fxt__stop__profiling.html":[7,0,0,137],
 "interfacefstarpu__mod_1_1fstarpu__fxt__write__data__trace.html":[6,0,0,138],
 "interfacefstarpu__mod_1_1fstarpu__fxt__write__data__trace.html":[7,0,0,138],
 "interfacefstarpu__mod_1_1fstarpu__get__version.html":[7,0,0,139],
 "interfacefstarpu__mod_1_1fstarpu__get__version.html":[6,0,0,139],
-"interfacefstarpu__mod_1_1fstarpu__insert__task.html":[7,0,0,140],
 "interfacefstarpu__mod_1_1fstarpu__insert__task.html":[6,0,0,140],
-"interfacefstarpu__mod_1_1fstarpu__is__paused.html":[6,0,0,141],
+"interfacefstarpu__mod_1_1fstarpu__insert__task.html":[7,0,0,140],
 "interfacefstarpu__mod_1_1fstarpu__is__paused.html":[7,0,0,141],
-"interfacefstarpu__mod_1_1fstarpu__malloc.html":[6,0,0,142],
+"interfacefstarpu__mod_1_1fstarpu__is__paused.html":[6,0,0,141],
 "interfacefstarpu__mod_1_1fstarpu__malloc.html":[7,0,0,142],
+"interfacefstarpu__mod_1_1fstarpu__malloc.html":[6,0,0,142],
 "interfacefstarpu__mod_1_1fstarpu__malloc__on__node.html":[6,0,0,143],
 "interfacefstarpu__mod_1_1fstarpu__malloc__on__node.html":[7,0,0,143],
-"interfacefstarpu__mod_1_1fstarpu__matrix__data__register.html":[7,0,0,144],
 "interfacefstarpu__mod_1_1fstarpu__matrix__data__register.html":[6,0,0,144],
-"interfacefstarpu__mod_1_1fstarpu__matrix__filter__block.html":[6,0,0,145],
+"interfacefstarpu__mod_1_1fstarpu__matrix__data__register.html":[7,0,0,144],
 "interfacefstarpu__mod_1_1fstarpu__matrix__filter__block.html":[7,0,0,145],
+"interfacefstarpu__mod_1_1fstarpu__matrix__filter__block.html":[6,0,0,145],
 "interfacefstarpu__mod_1_1fstarpu__matrix__filter__block__shadow.html":[6,0,0,146],
 "interfacefstarpu__mod_1_1fstarpu__matrix__filter__block__shadow.html":[7,0,0,146],
 "interfacefstarpu__mod_1_1fstarpu__matrix__filter__vertical__block.html":[7,0,0,147],
@@ -94,10 +95,10 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__pause.html":[6,0,0,161],
 "interfacefstarpu__mod_1_1fstarpu__perfmodel__allocate.html":[6,0,0,162],
 "interfacefstarpu__mod_1_1fstarpu__perfmodel__allocate.html":[7,0,0,162],
-"interfacefstarpu__mod_1_1fstarpu__perfmodel__free.html":[6,0,0,163],
 "interfacefstarpu__mod_1_1fstarpu__perfmodel__free.html":[7,0,0,163],
-"interfacefstarpu__mod_1_1fstarpu__perfmodel__set__symbol.html":[6,0,0,164],
+"interfacefstarpu__mod_1_1fstarpu__perfmodel__free.html":[6,0,0,163],
 "interfacefstarpu__mod_1_1fstarpu__perfmodel__set__symbol.html":[7,0,0,164],
+"interfacefstarpu__mod_1_1fstarpu__perfmodel__set__symbol.html":[6,0,0,164],
 "interfacefstarpu__mod_1_1fstarpu__perfmodel__set__type.html":[6,0,0,165],
 "interfacefstarpu__mod_1_1fstarpu__perfmodel__set__type.html":[7,0,0,165],
 "interfacefstarpu__mod_1_1fstarpu__resume.html":[6,0,0,166],
@@ -106,40 +107,40 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__add__workers.html":[7,0,0,167],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__bind__current__thread__to__cpuid.html":[6,0,0,168],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__bind__current__thread__to__cpuid.html":[7,0,0,168],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__book__workers__for__task.html":[7,0,0,169],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__book__workers__for__task.html":[6,0,0,169],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__call__pushed__task__cb.html":[7,0,0,170],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__book__workers__for__task.html":[7,0,0,169],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__call__pushed__task__cb.html":[6,0,0,170],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__type__of__worker.html":[6,0,0,171],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__call__pushed__task__cb.html":[7,0,0,170],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__type__of__worker.html":[7,0,0,171],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__type__of__worker.html":[6,0,0,171],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__worker.html":[7,0,0,172],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__contains__worker.html":[6,0,0,172],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__create.html":[7,0,0,173],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__create.html":[6,0,0,173],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__create__inside__interval.html":[6,0,0,174],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__create.html":[7,0,0,173],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__create__inside__interval.html":[7,0,0,174],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete.html":[6,0,0,175],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__create__inside__interval.html":[6,0,0,174],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete.html":[7,0,0,175],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete__worker__collection.html":[7,0,0,176],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete.html":[6,0,0,175],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete__worker__collection.html":[6,0,0,176],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__display__workers.html":[7,0,0,177],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__delete__worker__collection.html":[7,0,0,176],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__display__workers.html":[6,0,0,177],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__exec__parallel__code.html":[7,0,0,178],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__display__workers.html":[7,0,0,177],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__exec__parallel__code.html":[6,0,0,178],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__finished__submit.html":[6,0,0,179],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__exec__parallel__code.html":[7,0,0,178],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__finished__submit.html":[7,0,0,179],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__finished__submit.html":[6,0,0,179],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__context.html":[6,0,0,180],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__context.html":[7,0,0,180],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__ctx__for__task.html":[7,0,0,181],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__ctx__for__task.html":[6,0,0,181],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__hierarchy__level.html":[6,0,0,182],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__hierarchy__level.html":[7,0,0,182],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__inheritor.html":[6,0,0,183],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__inheritor.html":[7,0,0,183],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__inheritor.html":[6,0,0,183],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__max__priority.html":[6,0,0,184],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__max__priority.html":[7,0,0,184],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__min__priority.html":[6,0,0,185],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__min__priority.html":[7,0,0,185],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__min__priority.html":[6,0,0,185],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__flops.html":[7,0,0,186],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__flops.html":[6,0,0,186],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nready__tasks.html":[6,0,0,187],
@@ -148,68 +149,68 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nshared__workers.html":[7,0,0,188],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nworkers.html":[6,0,0,189],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__nworkers.html":[7,0,0,189],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__policy__data.html":[7,0,0,190],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__policy__data.html":[6,0,0,190],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__priority.html":[7,0,0,191],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__policy__data.html":[7,0,0,190],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__priority.html":[6,0,0,191],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__user__data.html":[7,0,0,192],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__priority.html":[7,0,0,191],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__user__data.html":[6,0,0,192],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__worker__rank.html":[7,0,0,193],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__user__data.html":[7,0,0,192],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__worker__rank.html":[6,0,0,193],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__get__worker__rank.html":[7,0,0,193],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement.html":[7,0,0,194],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement.html":[6,0,0,194],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement__all.html":[7,0,0,195],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__decrement__all.html":[6,0,0,195],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment.html":[6,0,0,196],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment.html":[7,0,0,196],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment.html":[6,0,0,196],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment__all.html":[7,0,0,197],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__increment__all.html":[6,0,0,197],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html":[6,0,0,198],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html":[7,0,0,198],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset.html":[6,0,0,198],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset__all.html":[7,0,0,199],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset__all.html":[6,0,0,199],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__master__get__context.html":[6,0,0,200],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__master__get__context.html":[7,0,0,200],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__max__priority__is__set.html":[6,0,0,201],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__max__priority__is__set.html":[7,0,0,201],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html":[6,0,0,202],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html":[7,0,0,202],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html":[6,0,0,203],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html":[6,0,0,202],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html":[7,0,0,203],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html":[6,0,0,203],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__overlapping__ctxs__on__worker.html":[6,0,0,204],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__overlapping__ctxs__on__worker.html":[7,0,0,204],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[6,0,0,205],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[7,0,0,205],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html":[6,0,0,206],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__register__close__callback.html":[6,0,0,205],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html":[7,0,0,206],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html":[6,0,0,207],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html":[6,0,0,206],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html":[7,0,0,207],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__context.html":[6,0,0,208],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__revert__task__counters.html":[6,0,0,207],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__context.html":[7,0,0,208],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__inheritor.html":[7,0,0,209],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__context.html":[6,0,0,208],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__inheritor.html":[6,0,0,209],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html":[7,0,0,210],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__inheritor.html":[7,0,0,209],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html":[6,0,0,210],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__min__priority.html":[7,0,0,211],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html":[7,0,0,210],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__min__priority.html":[6,0,0,211],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__policy__data.html":[7,0,0,212],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__min__priority.html":[7,0,0,211],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__policy__data.html":[6,0,0,212],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__policy__data.html":[7,0,0,212],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__stop__task__submission.html":[6,0,0,213],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__stop__task__submission.html":[7,0,0,213],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__unbook__workers__for__task.html":[6,0,0,214],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__unbook__workers__for__task.html":[7,0,0,214],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__get__id.html":[7,0,0,215],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__get__id.html":[6,0,0,215],
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__is__master__for__child__ctx.html":[7,0,0,216],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__get__id.html":[7,0,0,215],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__is__master__for__child__ctx.html":[6,0,0,216],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__is__master__for__child__ctx.html":[7,0,0,216],
 "interfacefstarpu__mod_1_1fstarpu__sched__get__max__priority.html":[7,0,0,217],
 "interfacefstarpu__mod_1_1fstarpu__sched__get__max__priority.html":[6,0,0,217],
-"interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html":[7,0,0,218],
 "interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html":[6,0,0,218],
-"interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[7,0,0,219],
+"interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html":[7,0,0,218],
 "interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[6,0,0,219],
-"interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[7,0,0,220],
+"interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[7,0,0,219],
 "interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[6,0,0,220],
+"interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[7,0,0,220],
 "interfacefstarpu__mod_1_1fstarpu__shutdown.html":[6,0,0,221],
 "interfacefstarpu__mod_1_1fstarpu__shutdown.html":[7,0,0,221],
 "interfacefstarpu__mod_1_1fstarpu__sleep.html":[6,0,0,222],
@@ -224,30 +225,29 @@ var NAVTREEINDEX11 =
 "interfacefstarpu__mod_1_1fstarpu__tag__remove.html":[7,0,0,226],
 "interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[6,0,0,227],
 "interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[7,0,0,227],
-"interfacefstarpu__mod_1_1fstarpu__tag__wait.html":[7,0,0,228],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait.html":[6,0,0,228],
+"interfacefstarpu__mod_1_1fstarpu__tag__wait.html":[7,0,0,228],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html":[6,0,0,229],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html":[7,0,0,229],
 "interfacefstarpu__mod_1_1fstarpu__task__clean.html":[7,0,0,230],
 "interfacefstarpu__mod_1_1fstarpu__task__clean.html":[6,0,0,230],
 "interfacefstarpu__mod_1_1fstarpu__task__create.html":[7,0,0,231],
 "interfacefstarpu__mod_1_1fstarpu__task__create.html":[6,0,0,231],
-"interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[6,0,0,232],
 "interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[7,0,0,232],
-"interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[6,0,0,233],
+"interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[6,0,0,232],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[7,0,0,233],
-"interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[7,0,0,234],
+"interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[6,0,0,233],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[6,0,0,234],
-"interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[7,0,0,235],
+"interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[7,0,0,234],
 "interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[6,0,0,235],
+"interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[7,0,0,235],
 "interfacefstarpu__mod_1_1fstarpu__task__dup.html":[7,0,0,236],
 "interfacefstarpu__mod_1_1fstarpu__task__dup.html":[6,0,0,236],
-"interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[6,0,0,237],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[7,0,0,237],
+"interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[6,0,0,237],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[7,0,0,238],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[6,0,0,238],
 "interfacefstarpu__mod_1_1fstarpu__task__finished.html":[7,0,0,239],
 "interfacefstarpu__mod_1_1fstarpu__task__finished.html":[6,0,0,239],
-"interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[6,0,0,240],
-"interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[7,0,0,240]
+"interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[6,0,0,240]
 };
