@@ -1,13 +1,14 @@
 var NAVTREEINDEX12 =
 {
+"interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[7,0,0,240],
 "interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[6,0,0,241],
 "interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[7,0,0,241],
 "interfacefstarpu__mod_1_1fstarpu__task__init.html":[6,0,0,242],
 "interfacefstarpu__mod_1_1fstarpu__task__init.html":[7,0,0,242],
-"interfacefstarpu__mod_1_1fstarpu__task__insert.html":[6,0,0,243],
 "interfacefstarpu__mod_1_1fstarpu__task__insert.html":[7,0,0,243],
-"interfacefstarpu__mod_1_1fstarpu__task__nready.html":[6,0,0,244],
+"interfacefstarpu__mod_1_1fstarpu__task__insert.html":[6,0,0,243],
 "interfacefstarpu__mod_1_1fstarpu__task__nready.html":[7,0,0,244],
+"interfacefstarpu__mod_1_1fstarpu__task__nready.html":[6,0,0,244],
 "interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[7,0,0,245],
 "interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[6,0,0,245],
 "interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[7,0,0,246],
@@ -22,30 +23,30 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__task__wait.html":[6,0,0,250],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[7,0,0,251],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[6,0,0,251],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[7,0,0,252],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[6,0,0,252],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[7,0,0,252],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[7,0,0,253],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[6,0,0,253],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[6,0,0,254],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[7,0,0,254],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[6,0,0,254],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[6,0,0,255],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[7,0,0,255],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[6,0,0,256],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[7,0,0,256],
-"interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[7,0,0,257],
 "interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[6,0,0,257],
+"interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[7,0,0,257],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[7,0,0,258],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[6,0,0,258],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[6,0,0,259],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[7,0,0,259],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[7,0,0,260],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[6,0,0,259],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[6,0,0,260],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[7,0,0,260],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[7,0,0,261],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[6,0,0,261],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[7,0,0,262],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[6,0,0,262],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[6,0,0,263],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[7,0,0,263],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[6,0,0,263],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html":[6,0,0,264],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nz.html":[7,0,0,264],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ptr.html":[6,0,0,265],
@@ -62,36 +63,36 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__unpack__arg.html":[7,0,0,270],
 "interfacefstarpu__mod_1_1fstarpu__usleep.html":[7,0,0,271],
 "interfacefstarpu__mod_1_1fstarpu__usleep.html":[6,0,0,271],
-"interfacefstarpu__mod_1_1fstarpu__variable__data__register.html":[6,0,0,272],
 "interfacefstarpu__mod_1_1fstarpu__variable__data__register.html":[7,0,0,272],
+"interfacefstarpu__mod_1_1fstarpu__variable__data__register.html":[6,0,0,272],
 "interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html":[6,0,0,273],
 "interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html":[7,0,0,273],
 "interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[6,0,0,274],
 "interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[7,0,0,274],
 "interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[6,0,0,275],
 "interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[7,0,0,275],
-"interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[7,0,0,276],
 "interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[6,0,0,276],
-"interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[6,0,0,277],
+"interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[7,0,0,276],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[7,0,0,277],
+"interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[6,0,0,277],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[6,0,0,278],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[7,0,0,278],
-"interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[7,0,0,279],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[6,0,0,279],
+"interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[7,0,0,279],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[7,0,0,280],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[6,0,0,280],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[7,0,0,281],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[6,0,0,281],
-"interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[6,0,0,282],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[7,0,0,282],
+"interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[6,0,0,282],
 "interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[6,0,0,283],
 "interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[7,0,0,283],
 "interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[6,0,0,284],
 "interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[7,0,0,284],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[7,0,0,285],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[6,0,0,285],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[7,0,0,286],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[7,0,0,285],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[6,0,0,286],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[7,0,0,286],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[7,0,0,287],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[6,0,0,287],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[7,0,0,288],
@@ -104,12 +105,12 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[6,0,0,291],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[7,0,0,292],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[6,0,0,292],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[7,0,0,293],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[6,0,0,293],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[6,0,0,294],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[7,0,0,293],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[7,0,0,294],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[6,0,0,295],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[6,0,0,294],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[7,0,0,295],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[6,0,0,295],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[7,0,0,296],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[6,0,0,296],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[7,0,0,297],
@@ -248,6 +249,5 @@ var NAVTREEINDEX12 =
 "sc__hypervisor__monitoring_8h.html#adfb3d97bbdc15b0f9acee62ab4ae6350":[8,0,3,0,3,0,8],
 "sc__hypervisor__monitoring_8h.html#adfbc9bbc2fb020e1b0c847f8557e45d6":[8,0,3,0,3,0,24],
 "sc__hypervisor__monitoring_8h.html#ae52f8e1b8fdfd299a91890cef366a00a":[8,0,3,0,3,0,23],
-"sc__hypervisor__monitoring_8h.html#ae60f91b9b83b82c3dd6ef43e7c8d730d":[8,0,3,0,3,0,28],
-"sc__hypervisor__monitoring_8h.html#aee6c9636c4ce6692556e0e87e4d16455":[8,0,3,0,3,0,11]
+"sc__hypervisor__monitoring_8h.html#ae60f91b9b83b82c3dd6ef43e7c8d730d":[8,0,3,0,3,0,28]
 };
