@@ -1,5 +1,6 @@
 var NAVTREEINDEX4 =
 {
+"group__API__Initialization__and__Termination.html#a515df0a157b0bebc3e3aeaf6dd95bb73":[5,4,0,35],
 "group__API__Initialization__and__Termination.html#a53d18b801302e2ccae6af09c6cdbb2c5":[5,4,0,33],
 "group__API__Initialization__and__Termination.html#a58cc3a37dc4e60999c2c99b0ec0244ad":[5,4,0,1],
 "group__API__Initialization__and__Termination.html#a5a36072143f87103ee20ad3aff00a3b1":[5,4,0,44],
@@ -248,6 +249,5 @@ var NAVTREEINDEX4 =
 "group__API__MPI__Support.html#ga633d2e3fef4861042eb42e214efa2e43":[5,27,42],
 "group__API__MPI__Support.html#ga63a3aa05bebafcc4b9cf67f73db6ecb6":[5,27,92],
 "group__API__MPI__Support.html#ga64b80afba4d16ef45a1baf4656a94c52":[5,27,81],
-"group__API__MPI__Support.html#ga67d1e5f67d39674590a2adc7c53ae185":[5,27,28],
-"group__API__MPI__Support.html#ga69699989814f54defa33b444e3e59c20":[5,27,116]
+"group__API__MPI__Support.html#ga67d1e5f67d39674590a2adc7c53ae185":[5,27,28]
 };
