@@ -1,5 +1,6 @@
 var NAVTREEINDEX5 =
 {
+"group__API__MPI__Support.html#ga69699989814f54defa33b444e3e59c20":[5,27,116],
 "group__API__MPI__Support.html#ga6b5f6d7fdf83ed6a9e7d7016cb67ca70":[5,27,101],
 "group__API__MPI__Support.html#ga6ebb836a816647d2f00977ea749e53bc":[5,27,94],
 "group__API__MPI__Support.html#ga70687c70156fa88dcaf7be605566f42e":[5,27,57],
@@ -134,79 +135,80 @@ var NAVTREEINDEX5 =
 "group__API__Modularized__Scheduler.html#abf315d3c1f60fbcab6a001f7925dc4fa":[5,22,0,12],
 "group__API__Modularized__Scheduler.html#ac2709f00c42977b8df96d30015fc9cb1":[5,22,0,19],
 "group__API__Modularized__Scheduler.html#ad859296dbded64c8593d613286893a93":[5,22,7,1],
-"group__API__Modularized__Scheduler.html#ga063bc22ea750afba5bebe22e3117258b":[5,22,24],
-"group__API__Modularized__Scheduler.html#ga0b4db1194be324a7cbd2c6486db867d7":[5,22,72],
-"group__API__Modularized__Scheduler.html#ga0c419ef90f6adce7cc9ebca955822dbb":[5,22,62],
-"group__API__Modularized__Scheduler.html#ga0e50b97229fdf62b5006eba35f4d5683":[5,22,23],
+"group__API__Modularized__Scheduler.html#ga063bc22ea750afba5bebe22e3117258b":[5,22,25],
+"group__API__Modularized__Scheduler.html#ga0b4db1194be324a7cbd2c6486db867d7":[5,22,73],
+"group__API__Modularized__Scheduler.html#ga0c419ef90f6adce7cc9ebca955822dbb":[5,22,63],
+"group__API__Modularized__Scheduler.html#ga0e50b97229fdf62b5006eba35f4d5683":[5,22,24],
 "group__API__Modularized__Scheduler.html#ga12e7e5b58b9aebb4f3084fa807c55c40":[5,22,14],
-"group__API__Modularized__Scheduler.html#ga1460e5ad34f360408b3a0003aa0a2b9f":[5,22,45],
-"group__API__Modularized__Scheduler.html#ga17b2f48b9873e1a1b842bb81ed22e972":[5,22,61],
-"group__API__Modularized__Scheduler.html#ga1fd3c2682a57ca9105965b942a5a1313":[5,22,46],
-"group__API__Modularized__Scheduler.html#ga217b0c2bb96b4aa5f0ccda71c2d81f00":[5,22,41],
-"group__API__Modularized__Scheduler.html#ga21df9bf6da463d3b945f0886939b637a":[5,22,48],
-"group__API__Modularized__Scheduler.html#ga231e99e5ce0ecca11b8affebf40bdd9a":[5,22,64],
-"group__API__Modularized__Scheduler.html#ga248d8a1f97615362cb60e78a7ffbf298":[5,22,70],
-"group__API__Modularized__Scheduler.html#ga2a0aac2afe33c1ef0bf3260de25be29e":[5,22,35],
-"group__API__Modularized__Scheduler.html#ga2f27b106110cf20f52ed20e68ecd8613":[5,22,74],
-"group__API__Modularized__Scheduler.html#ga305b8f17f3d49897cebe8376aaede5a2":[5,22,47],
-"group__API__Modularized__Scheduler.html#ga30b0cd3f3d64be88a163a31148c58f1f":[5,22,37],
-"group__API__Modularized__Scheduler.html#ga3ac4da6a19d9f0a34e870e20d6c34966":[5,22,71],
-"group__API__Modularized__Scheduler.html#ga3c60576fc0645bec4cd90c758545fd40":[5,22,75],
+"group__API__Modularized__Scheduler.html#ga1460e5ad34f360408b3a0003aa0a2b9f":[5,22,46],
+"group__API__Modularized__Scheduler.html#ga17b2f48b9873e1a1b842bb81ed22e972":[5,22,62],
+"group__API__Modularized__Scheduler.html#ga1fd3c2682a57ca9105965b942a5a1313":[5,22,47],
+"group__API__Modularized__Scheduler.html#ga217b0c2bb96b4aa5f0ccda71c2d81f00":[5,22,42],
+"group__API__Modularized__Scheduler.html#ga21df9bf6da463d3b945f0886939b637a":[5,22,49],
+"group__API__Modularized__Scheduler.html#ga231e99e5ce0ecca11b8affebf40bdd9a":[5,22,65],
+"group__API__Modularized__Scheduler.html#ga248d8a1f97615362cb60e78a7ffbf298":[5,22,71],
+"group__API__Modularized__Scheduler.html#ga2a0aac2afe33c1ef0bf3260de25be29e":[5,22,36],
+"group__API__Modularized__Scheduler.html#ga2f27b106110cf20f52ed20e68ecd8613":[5,22,75],
+"group__API__Modularized__Scheduler.html#ga305b8f17f3d49897cebe8376aaede5a2":[5,22,48],
+"group__API__Modularized__Scheduler.html#ga30b0cd3f3d64be88a163a31148c58f1f":[5,22,38],
+"group__API__Modularized__Scheduler.html#ga3ac4da6a19d9f0a34e870e20d6c34966":[5,22,72],
+"group__API__Modularized__Scheduler.html#ga3c60576fc0645bec4cd90c758545fd40":[5,22,76],
 "group__API__Modularized__Scheduler.html#ga3f9c54f338cb39029b508f5890b1111a":[5,22,17],
-"group__API__Modularized__Scheduler.html#ga424d5bae6d2c3c99ab4f215b0e23698f":[5,22,57],
-"group__API__Modularized__Scheduler.html#ga478058eac115f3889d6f39273d66a53f":[5,22,29],
-"group__API__Modularized__Scheduler.html#ga48a2bf7d22985f9a810f8a563153e936":[5,22,50],
-"group__API__Modularized__Scheduler.html#ga49a5e198c16a141aee76be2416b7dbb4":[5,22,78],
-"group__API__Modularized__Scheduler.html#ga4a02a60ffa8959fda08292dbf7aa20f7":[5,22,56],
-"group__API__Modularized__Scheduler.html#ga4fd6f598c30dac693e9e5b37f3e450f6":[5,22,66],
-"group__API__Modularized__Scheduler.html#ga502c075e94e2988007333d8f0f80b69c":[5,22,77],
-"group__API__Modularized__Scheduler.html#ga511a8c5bc261cae8153cdfe7670a21a4":[5,22,32],
-"group__API__Modularized__Scheduler.html#ga5c4ea8cd11d331eb39de2c02ce29efb1":[5,22,38],
-"group__API__Modularized__Scheduler.html#ga61c2f443fb8d5b6a2a1404eae0e7868e":[5,22,30],
-"group__API__Modularized__Scheduler.html#ga685a73facd82449b2f21f76f909e4ac3":[5,22,59],
-"group__API__Modularized__Scheduler.html#ga686ebaecfc562cacc98b20bbb7db5ebf":[5,22,33],
-"group__API__Modularized__Scheduler.html#ga699b31664bb3665f25ef360c2512d8f9":[5,22,58],
-"group__API__Modularized__Scheduler.html#ga70c74dee688684fb09e45833094ba21a":[5,22,26],
+"group__API__Modularized__Scheduler.html#ga424d5bae6d2c3c99ab4f215b0e23698f":[5,22,58],
+"group__API__Modularized__Scheduler.html#ga478058eac115f3889d6f39273d66a53f":[5,22,30],
+"group__API__Modularized__Scheduler.html#ga48a2bf7d22985f9a810f8a563153e936":[5,22,51],
+"group__API__Modularized__Scheduler.html#ga49a5e198c16a141aee76be2416b7dbb4":[5,22,79],
+"group__API__Modularized__Scheduler.html#ga4a02a60ffa8959fda08292dbf7aa20f7":[5,22,57],
+"group__API__Modularized__Scheduler.html#ga4fd6f598c30dac693e9e5b37f3e450f6":[5,22,67],
+"group__API__Modularized__Scheduler.html#ga502c075e94e2988007333d8f0f80b69c":[5,22,78],
+"group__API__Modularized__Scheduler.html#ga511a8c5bc261cae8153cdfe7670a21a4":[5,22,33],
+"group__API__Modularized__Scheduler.html#ga5c4ea8cd11d331eb39de2c02ce29efb1":[5,22,39],
+"group__API__Modularized__Scheduler.html#ga61c2f443fb8d5b6a2a1404eae0e7868e":[5,22,31],
+"group__API__Modularized__Scheduler.html#ga685a73facd82449b2f21f76f909e4ac3":[5,22,60],
+"group__API__Modularized__Scheduler.html#ga686ebaecfc562cacc98b20bbb7db5ebf":[5,22,34],
+"group__API__Modularized__Scheduler.html#ga699b31664bb3665f25ef360c2512d8f9":[5,22,59],
+"group__API__Modularized__Scheduler.html#ga6b1f65158357aae0d9239063e54f82a4":[5,22,21],
+"group__API__Modularized__Scheduler.html#ga70c74dee688684fb09e45833094ba21a":[5,22,27],
 "group__API__Modularized__Scheduler.html#ga72554d14205573f57631b850afa3f39f":[5,22,11],
-"group__API__Modularized__Scheduler.html#ga752889050651f6e3c83ddd2c3f96c0ff":[5,22,63],
-"group__API__Modularized__Scheduler.html#ga782b27a1b864b0d21294f3d8da8756f8":[5,22,60],
-"group__API__Modularized__Scheduler.html#ga79594b4403678fa1d6aa08f7fbe6e525":[5,22,44],
-"group__API__Modularized__Scheduler.html#ga795d692f797ef022c350c9b5922cec31":[5,22,40],
+"group__API__Modularized__Scheduler.html#ga752889050651f6e3c83ddd2c3f96c0ff":[5,22,64],
+"group__API__Modularized__Scheduler.html#ga782b27a1b864b0d21294f3d8da8756f8":[5,22,61],
+"group__API__Modularized__Scheduler.html#ga79594b4403678fa1d6aa08f7fbe6e525":[5,22,45],
+"group__API__Modularized__Scheduler.html#ga795d692f797ef022c350c9b5922cec31":[5,22,41],
 "group__API__Modularized__Scheduler.html#ga7bacda898bdd7964b21ce611c7db077b":[5,22,10],
-"group__API__Modularized__Scheduler.html#ga7ceaaeea8cc10f6d67706c4ee33e93ce":[5,22,36],
-"group__API__Modularized__Scheduler.html#ga813c6be6ae07ec5fe6e54a1bd97267ce":[5,22,21],
-"group__API__Modularized__Scheduler.html#ga862bc72530533cc7eab28294676f5318":[5,22,55],
-"group__API__Modularized__Scheduler.html#ga87785b9c9eeb3718d85dc1b2a24fab26":[5,22,28],
-"group__API__Modularized__Scheduler.html#ga8efad6df3a5b036619ea5c76fe50a0c5":[5,22,51],
-"group__API__Modularized__Scheduler.html#ga90dfe435a72d46bd23ddaffa287833c2":[5,22,39],
+"group__API__Modularized__Scheduler.html#ga7ceaaeea8cc10f6d67706c4ee33e93ce":[5,22,37],
+"group__API__Modularized__Scheduler.html#ga813c6be6ae07ec5fe6e54a1bd97267ce":[5,22,22],
+"group__API__Modularized__Scheduler.html#ga862bc72530533cc7eab28294676f5318":[5,22,56],
+"group__API__Modularized__Scheduler.html#ga87785b9c9eeb3718d85dc1b2a24fab26":[5,22,29],
+"group__API__Modularized__Scheduler.html#ga8efad6df3a5b036619ea5c76fe50a0c5":[5,22,52],
+"group__API__Modularized__Scheduler.html#ga90dfe435a72d46bd23ddaffa287833c2":[5,22,40],
 "group__API__Modularized__Scheduler.html#ga966aaa040948551bede3ee46c9f8847e":[5,22,18],
-"group__API__Modularized__Scheduler.html#ga9bfbf9eb07c5ccc7c77a40ddb37056b8":[5,22,67],
-"group__API__Modularized__Scheduler.html#ga9ed484d5707136420880285afe55bd3d":[5,22,43],
-"group__API__Modularized__Scheduler.html#gaa207453a69f029b2f3c74bc8b9cffde2":[5,22,69],
+"group__API__Modularized__Scheduler.html#ga9bfbf9eb07c5ccc7c77a40ddb37056b8":[5,22,68],
+"group__API__Modularized__Scheduler.html#ga9ed484d5707136420880285afe55bd3d":[5,22,44],
+"group__API__Modularized__Scheduler.html#gaa207453a69f029b2f3c74bc8b9cffde2":[5,22,70],
 "group__API__Modularized__Scheduler.html#gaa838921844068ca3190dca5e2b5a99db":[5,22,13],
-"group__API__Modularized__Scheduler.html#gaab8471a2921b0508b9269b08ecfba3b7":[5,22,42],
-"group__API__Modularized__Scheduler.html#gab17420484cfb68122d986d1feee91905":[5,22,76],
-"group__API__Modularized__Scheduler.html#gab40975877d0c861348ccc96602be2cae":[5,22,25],
-"group__API__Modularized__Scheduler.html#gab8540c0e69c3af17c424944af9b3c802":[5,22,27],
+"group__API__Modularized__Scheduler.html#gaab8471a2921b0508b9269b08ecfba3b7":[5,22,43],
+"group__API__Modularized__Scheduler.html#gab17420484cfb68122d986d1feee91905":[5,22,77],
+"group__API__Modularized__Scheduler.html#gab40975877d0c861348ccc96602be2cae":[5,22,26],
+"group__API__Modularized__Scheduler.html#gab8540c0e69c3af17c424944af9b3c802":[5,22,28],
 "group__API__Modularized__Scheduler.html#gabd7a0274979659050496fcc1c66b7a1c":[5,22,8],
-"group__API__Modularized__Scheduler.html#gabf51817bd8f2a32af327d90eb5d126ec":[5,22,54],
-"group__API__Modularized__Scheduler.html#gac3ab95326f770ecd208a9949d18ceddf":[5,22,65],
-"group__API__Modularized__Scheduler.html#gac863df9e289543dcfd6a0b5e4e60432a":[5,22,22],
-"group__API__Modularized__Scheduler.html#gaccfaa23c5e0948fec6be5f71fc69f32c":[5,22,73],
-"group__API__Modularized__Scheduler.html#gad06fa143512ae761c452bf0adf685bae":[5,22,53],
+"group__API__Modularized__Scheduler.html#gabf51817bd8f2a32af327d90eb5d126ec":[5,22,55],
+"group__API__Modularized__Scheduler.html#gac3ab95326f770ecd208a9949d18ceddf":[5,22,66],
+"group__API__Modularized__Scheduler.html#gac863df9e289543dcfd6a0b5e4e60432a":[5,22,23],
+"group__API__Modularized__Scheduler.html#gaccfaa23c5e0948fec6be5f71fc69f32c":[5,22,74],
+"group__API__Modularized__Scheduler.html#gad06fa143512ae761c452bf0adf685bae":[5,22,54],
 "group__API__Modularized__Scheduler.html#gad0e17cdc3def6bd7e9a9a17437969bdb":[5,22,19],
-"group__API__Modularized__Scheduler.html#gad76ac70069357b5a3d0ac0a1489016a2":[5,22,68],
+"group__API__Modularized__Scheduler.html#gad76ac70069357b5a3d0ac0a1489016a2":[5,22,69],
 "group__API__Modularized__Scheduler.html#gae1aa931285a2b952473fc7def121c5cd":[5,22,16],
-"group__API__Modularized__Scheduler.html#gae1ac4bb35944de31705ba297aef1f9a1":[5,22,49],
+"group__API__Modularized__Scheduler.html#gae1ac4bb35944de31705ba297aef1f9a1":[5,22,50],
 "group__API__Modularized__Scheduler.html#gae4532cd31d9d069b810bdf52db2e052e":[5,22,15],
 "group__API__Modularized__Scheduler.html#gae4fc13eee5dd3528951a5cfea33c03ce":[5,22,12],
-"group__API__Modularized__Scheduler.html#gae97d6b25d8143ef2f7b6260c6f550c5c":[5,22,31],
-"group__API__Modularized__Scheduler.html#gaec7ff28a32f69a93850a1233a1c2725f":[5,22,34],
+"group__API__Modularized__Scheduler.html#gae97d6b25d8143ef2f7b6260c6f550c5c":[5,22,32],
+"group__API__Modularized__Scheduler.html#gaec7ff28a32f69a93850a1233a1c2725f":[5,22,35],
 "group__API__Modularized__Scheduler.html#gafb485fe5fb1f46c7ce7eb505815f306b":[5,22,9],
 "group__API__Modularized__Scheduler.html#gafb5ce04aff2175aed3763a72bf252107":[5,22,20],
-"group__API__Modularized__Scheduler.html#gafb683e254b5084a1321a21fde5139b01":[5,22,52],
-"group__API__Modularized__Scheduler.html#ggab40975877d0c861348ccc96602be2caea27934b03d9ff6827b318124ff683fb40":[5,22,25,0],
-"group__API__Modularized__Scheduler.html#ggab40975877d0c861348ccc96602be2caea40dba09874d6d3a220669e0ccea27da2":[5,22,25,1],
+"group__API__Modularized__Scheduler.html#gafb683e254b5084a1321a21fde5139b01":[5,22,53],
+"group__API__Modularized__Scheduler.html#ggab40975877d0c861348ccc96602be2caea27934b03d9ff6827b318124ff683fb40":[5,22,26,0],
+"group__API__Modularized__Scheduler.html#ggab40975877d0c861348ccc96602be2caea40dba09874d6d3a220669e0ccea27da2":[5,22,26,1],
 "group__API__Modularized__Scheduler.html#structstarpu__sched__component":[5,22,0],
 "group__API__Modularized__Scheduler.html#structstarpu__sched__component__fifo__data":[5,22,2],
 "group__API__Modularized__Scheduler.html#structstarpu__sched__component__heteroprio__data":[5,22,5],
@@ -247,7 +249,5 @@ var NAVTREEINDEX5 =
 "group__API__OpenCL__Extensions.html#gad18d6a0dfbfadcb0fe0b2be6294aa87d":[5,15,10],
 "group__API__OpenCL__Extensions.html#gadc4689d1ad238ba0b296e205e3bb6317":[5,15,14],
 "group__API__OpenCL__Extensions.html#gae023af317c4040f926d2c50a8f96b5d2":[5,15,4],
-"group__API__OpenCL__Extensions.html#gaeaabc8e5d90531a21a8307c06c659984":[5,15,23],
-"group__API__OpenCL__Extensions.html#structstarpu__opencl__program":[5,15,0],
-"group__API__OpenMP__Runtime__Support.html":[5,21]
+"group__API__OpenCL__Extensions.html#gaeaabc8e5d90531a21a8307c06c659984":[5,15,23]
 };
