@@ -1,5 +1,7 @@
 var NAVTREEINDEX10 =
 {
+"group__API__Workers.html#ga4998e4e1dfa0d121059c60f790496a03":[7,18,24],
+"group__API__Workers.html#ga53bac558c693f8cfdeef94bc6b64ab0b":[7,18,53],
 "group__API__Workers.html#ga5728fe0e4be069e45c4cd0ac0319d8a0":[7,18,47],
 "group__API__Workers.html#ga57687262112024abc0082b01b72ff0e8":[7,18,59],
 "group__API__Workers.html#ga5877310a0fae5f20967027fcb214c7aa":[7,18,37],
@@ -70,82 +72,82 @@ var NAVTREEINDEX10 =
 "index.html":[],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[9,0,0,0],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[8,0,0,0],
-"interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[8,0,0,1],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[9,0,0,1],
+"interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[8,0,0,1],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[9,0,0,2],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[8,0,0,2],
-"interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[8,0,0,3],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[9,0,0,3],
+"interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[8,0,0,3],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[8,0,0,4],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[9,0,0,4],
 "interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[8,0,0,5],
 "interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[9,0,0,5],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[8,0,0,6],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[9,0,0,6],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[8,0,0,6],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[9,0,0,7],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[8,0,0,7],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[9,0,0,8],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[8,0,0,8],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[9,0,0,8],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[9,0,0,9],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[8,0,0,9],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[9,0,0,10],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[8,0,0,10],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[9,0,0,10],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[9,0,0,11],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[8,0,0,11],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[8,0,0,12],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[9,0,0,12],
-"interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[8,0,0,13],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[9,0,0,13],
-"interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[9,0,0,14],
+"interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[8,0,0,13],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[8,0,0,14],
-"interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[9,0,0,15],
+"interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[9,0,0,14],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[8,0,0,15],
-"interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[8,0,0,16],
+"interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[9,0,0,15],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[9,0,0,16],
+"interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[8,0,0,16],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[9,0,0,17],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[8,0,0,17],
-"interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[8,0,0,18],
 "interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[9,0,0,18],
+"interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[8,0,0,18],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[8,0,0,19],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[9,0,0,19],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[8,0,0,20],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[9,0,0,20],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[8,0,0,21],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[9,0,0,21],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[8,0,0,22],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[8,0,0,21],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[9,0,0,22],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[9,0,0,23],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[8,0,0,22],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[8,0,0,23],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[8,0,0,24],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[9,0,0,23],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[9,0,0,24],
-"interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[8,0,0,25],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[8,0,0,24],
 "interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[9,0,0,25],
+"interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[8,0,0,25],
 "interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html":[8,0,0,26],
 "interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html":[9,0,0,26],
-"interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[8,0,0,27],
 "interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[9,0,0,27],
+"interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[8,0,0,27],
 "interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[8,0,0,28],
 "interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[9,0,0,28],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[8,0,0,29],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[9,0,0,29],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[8,0,0,30],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[9,0,0,30],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[8,0,0,31],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[9,0,0,31],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[8,0,0,32],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[8,0,0,31],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[9,0,0,32],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[8,0,0,32],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[9,0,0,33],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[8,0,0,33],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[8,0,0,34],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[9,0,0,34],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[8,0,0,34],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[9,0,0,35],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[8,0,0,35],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[9,0,0,36],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[8,0,0,36],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[8,0,0,37],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[9,0,0,37],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[9,0,0,38],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[8,0,0,37],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[8,0,0,38],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[9,0,0,38],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html":[9,0,0,39],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html":[8,0,0,39],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html":[9,0,0,40],
@@ -166,8 +168,8 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__conf__set__min__prio.html":[8,0,0,47],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__ncpu.html":[9,0,0,48],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__ncpu.html":[8,0,0,48],
-"interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[9,0,0,49],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[8,0,0,49],
+"interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[9,0,0,49],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html":[9,0,0,50],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html":[8,0,0,50],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__sched__policy__name.html":[9,0,0,51],
@@ -180,74 +182,72 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__cublas__init.html":[8,0,0,54],
 "interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[9,0,0,55],
 "interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[8,0,0,55],
-"interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[9,0,0,56],
 "interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[8,0,0,56],
-"interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[9,0,0,57],
+"interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[9,0,0,56],
 "interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[8,0,0,57],
-"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[9,0,0,58],
+"interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[9,0,0,57],
 "interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[8,0,0,58],
-"interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[9,0,0,59],
+"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[9,0,0,58],
 "interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[8,0,0,59],
+"interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[9,0,0,59],
 "interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[8,0,0,60],
 "interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[9,0,0,60],
-"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[8,0,0,61],
 "interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[9,0,0,61],
-"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[8,0,0,62],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[8,0,0,61],
 "interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[9,0,0,62],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[8,0,0,63],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[8,0,0,62],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[9,0,0,63],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[8,0,0,63],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[9,0,0,64],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[8,0,0,64],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[8,0,0,65],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[9,0,0,65],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[8,0,0,66],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[8,0,0,65],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[9,0,0,66],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[8,0,0,67],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[8,0,0,66],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[9,0,0,67],
-"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[8,0,0,68],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[8,0,0,67],
 "interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[9,0,0,68],
-"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[8,0,0,69],
+"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[8,0,0,68],
 "interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[9,0,0,69],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[9,0,0,70],
+"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[8,0,0,69],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[8,0,0,70],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[9,0,0,70],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[9,0,0,71],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[8,0,0,71],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[9,0,0,72],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[8,0,0,72],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[9,0,0,73],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[9,0,0,72],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[8,0,0,73],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[9,0,0,74],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[9,0,0,73],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[8,0,0,74],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[9,0,0,74],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[8,0,0,75],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[9,0,0,75],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[9,0,0,76],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[8,0,0,76],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[9,0,0,76],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[9,0,0,77],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[8,0,0,77],
 "interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[9,0,0,78],
 "interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[8,0,0,78],
-"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[9,0,0,79],
 "interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[8,0,0,79],
-"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[8,0,0,80],
+"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[9,0,0,79],
 "interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[9,0,0,80],
-"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[8,0,0,81],
+"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[8,0,0,80],
 "interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[9,0,0,81],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[8,0,0,82],
+"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[8,0,0,81],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[9,0,0,82],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[8,0,0,82],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[9,0,0,83],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[8,0,0,83],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[9,0,0,84],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[8,0,0,84],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[9,0,0,85],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[8,0,0,85],
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[9,0,0,86],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[8,0,0,86],
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[9,0,0,87],
+"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[9,0,0,86],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[8,0,0,87],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[9,0,0,88],
+"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[9,0,0,87],
 "interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[8,0,0,88],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[9,0,0,89],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[9,0,0,88],
 "interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[8,0,0,89],
-"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[9,0,0,90],
-"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[8,0,0,90]
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[9,0,0,89]
 };
