@@ -1,5 +1,7 @@
 var NAVTREEINDEX13 =
 {
+"interfacestarpu__mod_1_1starpu__resume.html":[9,0,2,9],
+"interfacestarpu__mod_1_1starpu__shutdown.html":[9,0,2,10],
 "interfacestarpu__mod_1_1starpu__task__wait__for__all.html":[9,0,2,11],
 "modules.html":[7],
 "namespacefstarpu__mod.html#interfacefstarpu__mod_1_1operator_07_8ior_8_08":[10,0,1,1,0],
@@ -65,10 +67,10 @@ var NAVTREEINDEX13 =
 "starpu__bound_8h.html":[10,0,1,4],
 "starpu__bound_8h_source.html":[10,0,1,4],
 "starpu__config_8h.html":[10,0,0,0],
-"starpu__config_8h.html#a040eeaf64808762d84ff564d03090266":[10,0,0,0,11],
-"starpu__config_8h.html#a05ed4578d8a766626ad7a774483c9f5c":[10,0,0,0,28],
+"starpu__config_8h.html#a040eeaf64808762d84ff564d03090266":[10,0,0,0,12],
+"starpu__config_8h.html#a05ed4578d8a766626ad7a774483c9f5c":[10,0,0,0,29],
 "starpu__config_8h.html#a08a3c9825f3b8217c1089e97592caf80":[10,0,0,0,5],
-"starpu__config_8h.html#aa535e147c4094f10a17972c417f98d85":[10,0,0,0,27],
+"starpu__config_8h.html#aa535e147c4094f10a17972c417f98d85":[10,0,0,0,28],
 "starpu__config_8h.html#af3e493896eb70d1261709170f1a77c09":[10,0,0,0,4],
 "starpu__config_8h_source.html":[10,0,0,0],
 "starpu__cublas_8h.html":[10,0,1,5],
