@@ -16,18 +16,19 @@ var NAVTREEINDEX4 =
 "group__API__FxT__Support.html#structstarpu__fxt__mpi__offset":[7,34,1],
 "group__API__FxT__Support.html#structstarpu__fxt__options":[7,34,2],
 "group__API__HIP__Extensions.html":[7,16],
-"group__API__HIP__Extensions.html#ga1a691d2cef9367d76ba912bef672455f":[7,16,10],
-"group__API__HIP__Extensions.html#ga2b471b1bf5b6f10b347818f708c0a62f":[7,16,1],
+"group__API__HIP__Extensions.html#ga1a691d2cef9367d76ba912bef672455f":[7,16,11],
+"group__API__HIP__Extensions.html#ga2b471b1bf5b6f10b347818f708c0a62f":[7,16,2],
 "group__API__HIP__Extensions.html#ga2da78e5b8b0ff08d2b78d8cdffe1b48f":[7,16,0],
-"group__API__HIP__Extensions.html#ga4e209f6f83eaa6707c37cd60f1dac3ff":[7,16,7],
-"group__API__HIP__Extensions.html#ga81c617c18f5cc3e4799fd6858e5c6d3f":[7,16,6],
-"group__API__HIP__Extensions.html#ga9d7b2131ca9ed0d19535dcf5123145e2":[7,16,5],
-"group__API__HIP__Extensions.html#gaa67b3b12e9a0cce70c593b981ba14403":[7,16,8],
-"group__API__HIP__Extensions.html#gacb4a406b018e823790805c9d915dd052":[7,16,2],
-"group__API__HIP__Extensions.html#gad40f30899d319b57afe87e9f11e873e6":[7,16,11],
-"group__API__HIP__Extensions.html#gad433b07789156fd12e47cf35373d36c8":[7,16,3],
-"group__API__HIP__Extensions.html#gadc796fee8ebed3e8f4c12fb242f4c857":[7,16,4],
-"group__API__HIP__Extensions.html#gaea7ebef965850bb064607be8103e2c92":[7,16,9],
+"group__API__HIP__Extensions.html#ga4e209f6f83eaa6707c37cd60f1dac3ff":[7,16,8],
+"group__API__HIP__Extensions.html#ga81c617c18f5cc3e4799fd6858e5c6d3f":[7,16,7],
+"group__API__HIP__Extensions.html#ga895d3031a83129e4c874eadedcfb1912":[7,16,1],
+"group__API__HIP__Extensions.html#ga9d7b2131ca9ed0d19535dcf5123145e2":[7,16,6],
+"group__API__HIP__Extensions.html#gaa67b3b12e9a0cce70c593b981ba14403":[7,16,9],
+"group__API__HIP__Extensions.html#gacb4a406b018e823790805c9d915dd052":[7,16,3],
+"group__API__HIP__Extensions.html#gad40f30899d319b57afe87e9f11e873e6":[7,16,12],
+"group__API__HIP__Extensions.html#gad433b07789156fd12e47cf35373d36c8":[7,16,4],
+"group__API__HIP__Extensions.html#gadc796fee8ebed3e8f4c12fb242f4c857":[7,16,5],
+"group__API__HIP__Extensions.html#gaea7ebef965850bb064607be8103e2c92":[7,16,10],
 "group__API__HeteroPrio.html":[7,25],
 "group__API__HeteroPrio.html#ga08616241ba1e2b52a418b7de4c03895a":[7,25,7],
 "group__API__HeteroPrio.html#ga1756abbc3f96c7e3330313d00f40ba05":[7,25,4],
@@ -248,6 +249,5 @@ var NAVTREEINDEX4 =
 "group__API__Interop__Support.html#gaf6cca1c6f6a8d0a6cc73e8df687b4272":[7,50,16],
 "group__API__Interop__Support.html#gafbd3ffe388f6779226b4bb533e9e65d4":[7,50,59],
 "group__API__Interop__Support.html#gaff4a7845c85eeec3152526984a813cf6":[7,50,40],
-"group__API__Interop__Support.html#gaff61c047dc818553c56d9edeac379333":[7,50,29],
-"group__API__Interop__Support.html#gga33d15f419efaa08bf329d25f054fa632a23e7a45ff9fdffcc8241181af2d2f14e":[7,50,0,1]
+"group__API__Interop__Support.html#gaff61c047dc818553c56d9edeac379333":[7,50,29]
 };
