@@ -1,5 +1,7 @@
 var NAVTREEINDEX7 =
 {
+"group__API__Parallel__Worker.html#ga9adce159e1660dcd3ef111816b75b04d":[7,37,28],
+"group__API__Parallel__Worker.html#ga9b42af113646bf23c74e890fd766af31":[7,37,25],
 "group__API__Parallel__Worker.html#gab630219c3f24cfa1b3c096bdd19d5868":[7,37,27],
 "group__API__Parallel__Worker.html#gac1c6a21a2748744b1de17f432112c275":[7,37,10],
 "group__API__Parallel__Worker.html#gac1d014c1fb54af6193472ecfccc65575":[7,37,36],
@@ -247,7 +249,5 @@ var NAVTREEINDEX7 =
 "group__API__Profiling.html#ga858f465a2dcbcadb6169a7926e38a4d1":[7,40,12],
 "group__API__Profiling.html#ga87639260ff5c89f466e83fcc093e77fe":[7,40,20],
 "group__API__Profiling.html#ga8a423df93ec48a7391b2f439357a5544":[7,40,9],
-"group__API__Profiling.html#ga8cbf499dd0d62647b874fcb48c281e6a":[7,40,15],
-"group__API__Profiling.html#ga8dc4665fdbbbf8ce8f1b905aa8411642":[7,40,10],
-"group__API__Profiling.html#ga8ded3aa2a94ec7a5cd46e2e70a918c65":[7,40,13]
+"group__API__Profiling.html#ga8cbf499dd0d62647b874fcb48c281e6a":[7,40,15]
 };
