@@ -1,5 +1,7 @@
 var NAVTREEINDEX8 =
 {
+"group__API__Profiling.html#ga8dc4665fdbbbf8ce8f1b905aa8411642":[7,40,10],
+"group__API__Profiling.html#ga8ded3aa2a94ec7a5cd46e2e70a918c65":[7,40,13],
 "group__API__Profiling.html#ga9373d4a06c86ebf9ae74b67233b8bad6":[7,40,23],
 "group__API__Profiling.html#gabbb944b14c4378e5c855d060c730169b":[7,40,17],
 "group__API__Profiling.html#gabd03420d04882a63dea2f39d225ae9d2":[7,40,14],
@@ -247,7 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__Scheduling__Policy.html#ga24154b37920144de18bca59090429d6d":[7,24,18],
 "group__API__Scheduling__Policy.html#ga2bb5cf545414379c1425a4b399fd75c2":[7,24,6],
 "group__API__Scheduling__Policy.html#ga2c45db0c01e86497082c907b9cb0f4cc":[7,24,14],
-"group__API__Scheduling__Policy.html#ga2dc83adec9e479e967a1d1c2ae40f916":[7,24,30],
-"group__API__Scheduling__Policy.html#ga315482308105aa57ecc59e88f71823aa":[7,24,42],
-"group__API__Scheduling__Policy.html#ga318f5a51b8f948940c754df6962be263":[7,24,35]
+"group__API__Scheduling__Policy.html#ga2dc83adec9e479e967a1d1c2ae40f916":[7,24,30]
 };
