@@ -163,15 +163,15 @@ var NAVTREEINDEX =
 "group__API__Data__Interfaces.html#a99f4a2889d2184c091620140fa517e37",
 "group__API__Data__Interfaces.html#gadcf7063b1cd8d0feed7054e6e4d9d217",
 "group__API__Explicit__Dependencies.html#gabaef95d742d03c96453905602e511050",
-"group__API__Interop__Support.html#ga8e54df808c4f642b8fea3277dde90e2e",
-"group__API__Modularized__Scheduler.html#ga70c74dee688684fb09e45833094ba21a",
-"group__API__Parallel__Worker.html#ga01d8f8727b395aa7b49b77772b43f215",
-"group__API__Profiling.html#a8786d0be02dcf901ae7cd8a295b30293",
-"group__API__Scheduling__Contexts.html#gaf9a95bcf18710622750367c0ba6acbb4",
-"group__API__Workers.html#ga0dd6ff2d77c6a520a6cc4c051eb40bfa",
-"interfacefstarpu__mod_1_1fstarpu__data__get__child.html",
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__move__task__to__ctx.html",
-"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__send.html"
+"group__API__Interop__Support.html#ga8a6b1a42180b3e601e891d726dcf4997",
+"group__API__Modularized__Scheduler.html#ga699b31664bb3665f25ef360c2512d8f9",
+"group__API__Parallel__Tasks.html#gaf99bc08bf6f586b658febdd1dc6fef80",
+"group__API__Profiling.html#a78e32404bdff71292562d2dc5892061c",
+"group__API__Scheduling__Contexts.html#gaeb43bd3c56edb4bc4590eecc4eae76f0",
+"group__API__Workers.html#ga03d66f459ebae08349fa50042fe37808",
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html",
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html",
+"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__req__free.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
