@@ -1,5 +1,7 @@
 var NAVTREEINDEX10 =
 {
+"group__API__Workers.html#ga03d66f459ebae08349fa50042fe37808":[6,18,46],
+"group__API__Workers.html#ga0c9b9b7f5195cb8cbc5ee1223ec0f264":[6,18,34],
 "group__API__Workers.html#ga0dd6ff2d77c6a520a6cc4c051eb40bfa":[6,18,18],
 "group__API__Workers.html#ga1056809a8cd464002ed4cad02cec33e4":[6,18,67],
 "group__API__Workers.html#ga130075042017ad3794ba2321743088c6":[6,18,50],
@@ -94,68 +96,68 @@ var NAVTREEINDEX10 =
 "group__API__Workers.html#structstarpu__sched__ctx__iterator":[6,18,0],
 "group__API__Workers.html#structstarpu__worker__collection":[6,18,1],
 "index.html":[],
-"interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[7,0,0,0],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[8,0,0,0],
+"interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[7,0,0,0],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[7,0,0,1],
 "interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[8,0,0,1],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[8,0,0,2],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[7,0,0,2],
-"interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[7,0,0,3],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[8,0,0,3],
+"interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[7,0,0,3],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[8,0,0,4],
 "interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[7,0,0,4],
-"interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[7,0,0,5],
 "interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[8,0,0,5],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[7,0,0,6],
+"interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[7,0,0,5],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[8,0,0,6],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[7,0,0,6],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[8,0,0,7],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[7,0,0,7],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[7,0,0,8],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[8,0,0,8],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[7,0,0,8],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[8,0,0,9],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[7,0,0,9],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[8,0,0,10],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[7,0,0,10],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[8,0,0,10],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[8,0,0,11],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[7,0,0,11],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[8,0,0,12],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[7,0,0,12],
-"interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[8,0,0,13],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[7,0,0,13],
+"interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[8,0,0,13],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[7,0,0,14],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[8,0,0,14],
-"interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[8,0,0,15],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[7,0,0,15],
+"interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[8,0,0,15],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[7,0,0,16],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[8,0,0,16],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[7,0,0,17],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[8,0,0,17],
-"interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[7,0,0,18],
 "interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[8,0,0,18],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[8,0,0,19],
+"interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[7,0,0,18],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[7,0,0,19],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[8,0,0,19],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[7,0,0,20],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[8,0,0,20],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[8,0,0,21],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[7,0,0,21],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[8,0,0,21],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[7,0,0,22],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[8,0,0,22],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[7,0,0,23],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[8,0,0,23],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[7,0,0,23],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[7,0,0,24],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[8,0,0,24],
 "interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[7,0,0,25],
 "interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[8,0,0,25],
 "interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html":[7,0,0,26],
 "interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html":[8,0,0,26],
-"interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[8,0,0,27],
 "interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[7,0,0,27],
-"interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[7,0,0,28],
+"interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[8,0,0,27],
 "interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[8,0,0,28],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[7,0,0,29],
+"interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[7,0,0,28],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[8,0,0,29],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[7,0,0,30],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[7,0,0,29],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[8,0,0,30],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[7,0,0,30],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[7,0,0,31],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[8,0,0,31],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[7,0,0,32],
@@ -168,86 +170,84 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[7,0,0,35],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[8,0,0,36],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[7,0,0,36],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[7,0,0,37],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[8,0,0,37],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[7,0,0,37],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[7,0,0,38],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[8,0,0,38],
-"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html":[8,0,0,39],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html":[7,0,0,39],
-"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html":[8,0,0,40],
+"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html":[8,0,0,39],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html":[7,0,0,40],
-"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__rank.html":[8,0,0,41],
+"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html":[8,0,0,40],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__rank.html":[7,0,0,41],
-"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__size.html":[8,0,0,42],
+"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__rank.html":[8,0,0,41],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__size.html":[7,0,0,42],
-"interfacefstarpu__mod_1_1fstarpu__conf__allocate.html":[8,0,0,43],
+"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__size.html":[8,0,0,42],
 "interfacefstarpu__mod_1_1fstarpu__conf__allocate.html":[7,0,0,43],
+"interfacefstarpu__mod_1_1fstarpu__conf__allocate.html":[8,0,0,43],
 "interfacefstarpu__mod_1_1fstarpu__conf__free.html":[7,0,0,44],
 "interfacefstarpu__mod_1_1fstarpu__conf__free.html":[8,0,0,44],
 "interfacefstarpu__mod_1_1fstarpu__conf__init.html":[8,0,0,45],
 "interfacefstarpu__mod_1_1fstarpu__conf__init.html":[7,0,0,45],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__max__prio.html":[8,0,0,46],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__max__prio.html":[7,0,0,46],
-"interfacefstarpu__mod_1_1fstarpu__conf__set__min__prio.html":[8,0,0,47],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__min__prio.html":[7,0,0,47],
-"interfacefstarpu__mod_1_1fstarpu__conf__set__ncpu.html":[8,0,0,48],
+"interfacefstarpu__mod_1_1fstarpu__conf__set__min__prio.html":[8,0,0,47],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__ncpu.html":[7,0,0,48],
-"interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[8,0,0,49],
+"interfacefstarpu__mod_1_1fstarpu__conf__set__ncpu.html":[8,0,0,48],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[7,0,0,49],
-"interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html":[8,0,0,50],
+"interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[8,0,0,49],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html":[7,0,0,50],
+"interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html":[8,0,0,50],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__sched__policy__name.html":[8,0,0,51],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__sched__policy__name.html":[7,0,0,51],
 "interfacefstarpu__mod_1_1fstarpu__cpu__worker__get__count.html":[8,0,0,52],
 "interfacefstarpu__mod_1_1fstarpu__cpu__worker__get__count.html":[7,0,0,52],
-"interfacefstarpu__mod_1_1fstarpu__create__sync__task.html":[7,0,0,53],
 "interfacefstarpu__mod_1_1fstarpu__create__sync__task.html":[8,0,0,53],
-"interfacefstarpu__mod_1_1fstarpu__cublas__init.html":[8,0,0,54],
+"interfacefstarpu__mod_1_1fstarpu__create__sync__task.html":[7,0,0,53],
 "interfacefstarpu__mod_1_1fstarpu__cublas__init.html":[7,0,0,54],
-"interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[8,0,0,55],
+"interfacefstarpu__mod_1_1fstarpu__cublas__init.html":[8,0,0,54],
 "interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[7,0,0,55],
+"interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[8,0,0,55],
 "interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[7,0,0,56],
 "interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[8,0,0,56],
 "interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[7,0,0,57],
 "interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[8,0,0,57],
-"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[8,0,0,58],
 "interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[7,0,0,58],
-"interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[8,0,0,59],
+"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[8,0,0,58],
 "interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[7,0,0,59],
-"interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[8,0,0,60],
+"interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[8,0,0,59],
 "interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[7,0,0,60],
-"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[8,0,0,61],
+"interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[8,0,0,60],
 "interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[7,0,0,61],
-"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[8,0,0,62],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[8,0,0,61],
 "interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[7,0,0,62],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[8,0,0,63],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[8,0,0,62],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[7,0,0,63],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[7,0,0,64],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[8,0,0,63],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[8,0,0,64],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[7,0,0,65],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[7,0,0,64],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[8,0,0,65],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[7,0,0,66],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[7,0,0,65],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[8,0,0,66],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[7,0,0,67],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[7,0,0,66],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[8,0,0,67],
-"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[7,0,0,68],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[7,0,0,67],
 "interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[8,0,0,68],
+"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[7,0,0,68],
 "interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[8,0,0,69],
 "interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[7,0,0,69],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[8,0,0,70],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[7,0,0,70],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[8,0,0,70],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[7,0,0,71],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[8,0,0,71],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[7,0,0,72],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[8,0,0,72],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[7,0,0,73],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[8,0,0,73],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[8,0,0,74],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[7,0,0,74],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[8,0,0,74],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[8,0,0,75],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[7,0,0,75],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[8,0,0,76],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[7,0,0,76],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[7,0,0,77],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[8,0,0,77]
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[8,0,0,76]
 };
