@@ -1,5 +1,7 @@
 var NAVTREEINDEX13 =
 {
+"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__req__free.html":[8,0,1,52],
+"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__scatter__detached.html":[8,0,1,53],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__send.html":[8,0,1,54],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__send__prio.html":[8,0,1,55],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__set__communication__tag.html":[8,0,1,56],
@@ -91,10 +93,10 @@ var NAVTREEINDEX13 =
 "starpu__bound_8h.html":[9,0,1,4],
 "starpu__bound_8h_source.html":[9,0,1,4],
 "starpu__config_8h.html":[9,0,0,0],
-"starpu__config_8h.html#a040eeaf64808762d84ff564d03090266":[9,0,0,0,11],
-"starpu__config_8h.html#a05ed4578d8a766626ad7a774483c9f5c":[9,0,0,0,28],
+"starpu__config_8h.html#a040eeaf64808762d84ff564d03090266":[9,0,0,0,12],
+"starpu__config_8h.html#a05ed4578d8a766626ad7a774483c9f5c":[9,0,0,0,29],
 "starpu__config_8h.html#a08a3c9825f3b8217c1089e97592caf80":[9,0,0,0,5],
-"starpu__config_8h.html#aa535e147c4094f10a17972c417f98d85":[9,0,0,0,27],
+"starpu__config_8h.html#aa535e147c4094f10a17972c417f98d85":[9,0,0,0,28],
 "starpu__config_8h.html#af3e493896eb70d1261709170f1a77c09":[9,0,0,0,4],
 "starpu__config_8h_source.html":[9,0,0,0],
 "starpu__cublas_8h.html":[9,0,1,5],
