@@ -1,5 +1,7 @@
 var NAVTREEINDEX9 =
 {
+"group__API__Scheduling__Contexts.html#gaeb43bd3c56edb4bc4590eecc4eae76f0":[6,23,6],
+"group__API__Scheduling__Contexts.html#gaf213c18d752d78286cff68a379ee7611":[6,23,10],
 "group__API__Scheduling__Contexts.html#gaf9a95bcf18710622750367c0ba6acbb4":[6,23,34],
 "group__API__Scheduling__Contexts.html#gafe295aec3c152fe1fc0dd74e17f82961":[6,23,22],
 "group__API__Scheduling__Policy.html":[6,24],
@@ -247,7 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__Workers.html#acbe5dc434c779fec539a427b8e8ab1aa":[6,18,1,2],
 "group__API__Workers.html#adf52d25f085ea1f6fe2b982b3439b73f":[6,18,1,7],
 "group__API__Workers.html#ae039a760cdd80c0d91bcc4c4da9ebb74":[6,18,1,5],
-"group__API__Workers.html#ae260b3aeb9f58a98d7adb70eea8b851c":[6,18,1,9],
-"group__API__Workers.html#ga03d66f459ebae08349fa50042fe37808":[6,18,46],
-"group__API__Workers.html#ga0c9b9b7f5195cb8cbc5ee1223ec0f264":[6,18,34]
+"group__API__Workers.html#ae260b3aeb9f58a98d7adb70eea8b851c":[6,18,1,9]
 };
